@@ -14,6 +14,7 @@ use tower_lsp::{Client, LanguageServer};
 
 use crate::config::Config;
 use crate::lsp::types::{RumdlLspConfig, warning_to_code_action, warning_to_diagnostic};
+use crate::rule::Rule;
 use crate::rules;
 
 /// Main LSP server for rumdl
@@ -44,6 +45,31 @@ impl RumdlLanguageServer {
         }
     }
 
+    /// Apply LSP config overrides to the filtered rules
+    fn apply_lsp_config_overrides(
+        &self,
+        mut filtered_rules: Vec<Box<dyn Rule>>,
+        lsp_config: &RumdlLspConfig,
+    ) -> Vec<Box<dyn Rule>> {
+        // Apply enable_rules override from LSP config (if specified, only these rules are active)
+        if let Some(enable) = &lsp_config.enable_rules
+            && !enable.is_empty()
+        {
+            let enable_set: std::collections::HashSet<String> = enable.iter().cloned().collect();
+            filtered_rules.retain(|rule| enable_set.contains(rule.name()));
+        }
+
+        // Apply disable_rules override from LSP config
+        if let Some(disable) = &lsp_config.disable_rules
+            && !disable.is_empty()
+        {
+            let disable_set: std::collections::HashSet<String> = disable.iter().cloned().collect();
+            filtered_rules.retain(|rule| !disable_set.contains(rule.name()));
+        }
+
+        filtered_rules
+    }
+
     /// Lint a document and return diagnostics
     async fn lint_document(&self, uri: &Url, text: &str) -> Result<Vec<Diagnostic>> {
         let config_guard = self.config.read().await;
@@ -53,15 +79,23 @@ impl RumdlLanguageServer {
             return Ok(Vec::new());
         }
 
+        let lsp_config = config_guard.clone();
         drop(config_guard); // Release config lock early
 
         // Get rumdl configuration
         let rumdl_config = self.rumdl_config.read().await;
         let all_rules = rules::all_rules(&rumdl_config);
+        let flavor = rumdl_config.markdown_flavor();
+
+        // Use the standard filter_rules function which respects config's disabled rules
+        let mut filtered_rules = rules::filter_rules(&all_rules, &rumdl_config.global);
         drop(rumdl_config); // Release config lock early
 
-        // Run rumdl linting
-        match crate::lint(text, &all_rules, false) {
+        // Apply LSP config overrides (select_rules, ignore_rules from VSCode settings)
+        filtered_rules = self.apply_lsp_config_overrides(filtered_rules, &lsp_config);
+
+        // Run rumdl linting with the configured flavor
+        match crate::lint(text, &filtered_rules, false, flavor) {
             Ok(warnings) => {
                 let diagnostics = warnings.iter().map(warning_to_diagnostic).collect();
                 Ok(diagnostics)
@@ -87,16 +121,27 @@ impl RumdlLanguageServer {
 
     /// Apply all available fixes to a document
     async fn apply_all_fixes(&self, _uri: &Url, text: &str) -> Result<Option<String>> {
+        let config_guard = self.config.read().await;
+        let lsp_config = config_guard.clone();
+        drop(config_guard);
+
         let rumdl_config = self.rumdl_config.read().await;
         let all_rules = rules::all_rules(&rumdl_config);
+        let flavor = rumdl_config.markdown_flavor();
+
+        // Use the standard filter_rules function which respects config's disabled rules
+        let mut filtered_rules = rules::filter_rules(&all_rules, &rumdl_config.global);
         drop(rumdl_config);
 
+        // Apply LSP config overrides (select_rules, ignore_rules from VSCode settings)
+        filtered_rules = self.apply_lsp_config_overrides(filtered_rules, &lsp_config);
+
         // Apply fixes sequentially for each rule
         let mut fixed_text = text.to_string();
         let mut any_changes = false;
 
-        for rule in &all_rules {
-            let ctx = crate::lint_context::LintContext::new(&fixed_text);
+        for rule in &filtered_rules {
+            let ctx = crate::lint_context::LintContext::new(&fixed_text, flavor);
             match rule.fix(&ctx) {
                 Ok(new_text) => {
                     if new_text != fixed_text {
@@ -123,24 +168,92 @@ impl RumdlLanguageServer {
 
     /// Get code actions for diagnostics at a position
     async fn get_code_actions(&self, uri: &Url, text: &str, range: Range) -> Result<Vec<CodeAction>> {
+        let config_guard = self.config.read().await;
+        let lsp_config = config_guard.clone();
+        drop(config_guard);
+
         let rumdl_config = self.rumdl_config.read().await;
         let all_rules = rules::all_rules(&rumdl_config);
+        let flavor = rumdl_config.markdown_flavor();
+
+        // Use the standard filter_rules function which respects config's disabled rules
+        let mut filtered_rules = rules::filter_rules(&all_rules, &rumdl_config.global);
         drop(rumdl_config);
 
-        match crate::lint(text, &all_rules, false) {
+        // Apply LSP config overrides (select_rules, ignore_rules from VSCode settings)
+        filtered_rules = self.apply_lsp_config_overrides(filtered_rules, &lsp_config);
+
+        match crate::lint(text, &filtered_rules, false, flavor) {
             Ok(warnings) => {
                 let mut actions = Vec::new();
+                let mut fixable_count = 0;
 
-                for warning in warnings {
+                for warning in &warnings {
                     // Check if warning is within the requested range
                     let warning_line = (warning.line.saturating_sub(1)) as u32;
-                    if warning_line >= range.start.line && warning_line <= range.end.line {
-                        if let Some(action) = warning_to_code_action(&warning, uri, text) {
-                            actions.push(action);
+                    if warning_line >= range.start.line
+                        && warning_line <= range.end.line
+                        && let Some(action) = warning_to_code_action(warning, uri, text)
+                    {
+                        actions.push(action);
+                        if warning.fix.is_some() {
+                            fixable_count += 1;
                         }
                     }
                 }
 
+                // Add "Fix all" action if there are multiple fixable issues in range
+                if fixable_count > 1 {
+                    // Count total fixable issues in the document
+                    let total_fixable = warnings.iter().filter(|w| w.fix.is_some()).count();
+
+                    if let Ok(fixed_content) = crate::utils::fix_utils::apply_warning_fixes(text, &warnings)
+                        && fixed_content != text
+                    {
+                        // Calculate proper end position
+                        let mut line = 0u32;
+                        let mut character = 0u32;
+                        for ch in text.chars() {
+                            if ch == '\n' {
+                                line += 1;
+                                character = 0;
+                            } else {
+                                character += 1;
+                            }
+                        }
+
+                        let fix_all_action = CodeAction {
+                            title: format!("Fix all rumdl issues ({total_fixable} fixable)"),
+                            kind: Some(CodeActionKind::QUICKFIX),
+                            diagnostics: Some(Vec::new()),
+                            edit: Some(WorkspaceEdit {
+                                changes: Some(
+                                    [(
+                                        uri.clone(),
+                                        vec![TextEdit {
+                                            range: Range {
+                                                start: Position { line: 0, character: 0 },
+                                                end: Position { line, character },
+                                            },
+                                            new_text: fixed_content,
+                                        }],
+                                    )]
+                                    .into_iter()
+                                    .collect(),
+                                ),
+                                ..Default::default()
+                            }),
+                            command: None,
+                            is_preferred: Some(true),
+                            disabled: None,
+                            data: None,
+                        };
+
+                        // Insert at the beginning to make it prominent
+                        actions.insert(0, fix_all_action);
+                    }
+                }
+
                 Ok(actions)
             }
             Err(e) => {
@@ -204,10 +317,10 @@ impl LanguageServer for RumdlLanguageServer {
         log::info!("Initializing rumdl Language Server");
 
         // Parse client capabilities and configuration
-        if let Some(options) = params.initialization_options {
-            if let Ok(config) = serde_json::from_value::<RumdlLspConfig>(options) {
-                *self.config.write().await = config;
-            }
+        if let Some(options) = params.initialization_options
+            && let Ok(config) = serde_json::from_value::<RumdlLspConfig>(options)
+        {
+            *self.config.write().await = config;
         }
 
         // Load rumdl configuration with auto-discovery
@@ -217,6 +330,7 @@ impl LanguageServer for RumdlLanguageServer {
             capabilities: ServerCapabilities {
                 text_document_sync: Some(TextDocumentSyncCapability::Kind(TextDocumentSyncKind::FULL)),
                 code_action_provider: Some(CodeActionProviderCapability::Simple(true)),
+                document_formatting_provider: Some(OneOf::Left(true)),
                 diagnostic_provider: Some(DiagnosticServerCapabilities::Options(DiagnosticOptions {
                     identifier: Some("rumdl".to_string()),
                     inter_file_dependencies: false,
@@ -289,53 +403,51 @@ impl LanguageServer for RumdlLanguageServer {
         drop(config_guard);
 
         // Auto-fix on save if enabled
-        if enable_auto_fix {
-            if let Some(text) = self.documents.read().await.get(&params.text_document.uri) {
-                match self.apply_all_fixes(&params.text_document.uri, text).await {
-                    Ok(Some(fixed_text)) => {
-                        // Create a workspace edit to apply the fixes
-                        let edit = TextEdit {
-                            range: Range {
-                                start: Position { line: 0, character: 0 },
-                                end: self.get_end_position(text),
-                            },
-                            new_text: fixed_text.clone(),
-                        };
+        if enable_auto_fix && let Some(text) = self.documents.read().await.get(&params.text_document.uri) {
+            match self.apply_all_fixes(&params.text_document.uri, text).await {
+                Ok(Some(fixed_text)) => {
+                    // Create a workspace edit to apply the fixes
+                    let edit = TextEdit {
+                        range: Range {
+                            start: Position { line: 0, character: 0 },
+                            end: self.get_end_position(text),
+                        },
+                        new_text: fixed_text.clone(),
+                    };
 
-                        let mut changes = std::collections::HashMap::new();
-                        changes.insert(params.text_document.uri.clone(), vec![edit]);
+                    let mut changes = std::collections::HashMap::new();
+                    changes.insert(params.text_document.uri.clone(), vec![edit]);
 
-                        let workspace_edit = WorkspaceEdit {
-                            changes: Some(changes),
-                            document_changes: None,
-                            change_annotations: None,
-                        };
+                    let workspace_edit = WorkspaceEdit {
+                        changes: Some(changes),
+                        document_changes: None,
+                        change_annotations: None,
+                    };
 
-                        // Apply the edit
-                        match self.client.apply_edit(workspace_edit).await {
-                            Ok(response) => {
-                                if response.applied {
-                                    log::info!("Auto-fix applied successfully");
-                                    // Update our stored version
-                                    self.documents
-                                        .write()
-                                        .await
-                                        .insert(params.text_document.uri.clone(), fixed_text);
-                                } else {
-                                    log::warn!("Auto-fix was not applied: {:?}", response.failure_reason);
-                                }
-                            }
-                            Err(e) => {
-                                log::error!("Failed to apply auto-fix: {e}");
+                    // Apply the edit
+                    match self.client.apply_edit(workspace_edit).await {
+                        Ok(response) => {
+                            if response.applied {
+                                log::info!("Auto-fix applied successfully");
+                                // Update our stored version
+                                self.documents
+                                    .write()
+                                    .await
+                                    .insert(params.text_document.uri.clone(), fixed_text);
+                            } else {
+                                log::warn!("Auto-fix was not applied: {:?}", response.failure_reason);
                             }
                         }
+                        Err(e) => {
+                            log::error!("Failed to apply auto-fix: {e}");
+                        }
                     }
-                    Ok(None) => {
-                        log::debug!("No fixes to apply");
-                    }
-                    Err(e) => {
-                        log::error!("Failed to generate fixes: {e}");
-                    }
+                }
+                Ok(None) => {
+                    log::debug!("No fixes to apply");
+                }
+                Err(e) => {
+                    log::error!("Failed to generate fixes: {e}");
                 }
             }
         }
@@ -377,6 +489,75 @@ impl LanguageServer for RumdlLanguageServer {
         }
     }
 
+    async fn formatting(&self, params: DocumentFormattingParams) -> JsonRpcResult<Option<Vec<TextEdit>>> {
+        let uri = params.text_document.uri;
+
+        if let Some(text) = self.documents.read().await.get(&uri) {
+            // Get all rules from config
+            let rumdl_config = self.rumdl_config.read().await;
+            let all_rules = rules::all_rules(&rumdl_config);
+            let flavor = rumdl_config.markdown_flavor();
+
+            // Use the standard filter_rules function which respects config's disabled rules
+            let filtered_rules = rules::filter_rules(&all_rules, &rumdl_config.global);
+            drop(rumdl_config);
+
+            // Lint the document to get all warnings
+            match crate::lint(text, &filtered_rules, false, flavor) {
+                Ok(warnings) => {
+                    // Check if there are any fixable warnings
+                    let has_fixes = warnings.iter().any(|w| w.fix.is_some());
+
+                    if has_fixes {
+                        // Apply fixes using the fix_utils function
+                        match crate::utils::fix_utils::apply_warning_fixes(text, &warnings) {
+                            Ok(fixed_content) => {
+                                // Only return edits if the content actually changed
+                                if fixed_content != *text {
+                                    // Create a single TextEdit that replaces the entire document
+                                    // Calculate proper end position by iterating through all characters
+                                    let mut line = 0u32;
+                                    let mut character = 0u32;
+
+                                    for ch in text.chars() {
+                                        if ch == '\n' {
+                                            line += 1;
+                                            character = 0;
+                                        } else {
+                                            character += 1;
+                                        }
+                                    }
+
+                                    let edit = TextEdit {
+                                        range: Range {
+                                            start: Position { line: 0, character: 0 },
+                                            end: Position { line, character },
+                                        },
+                                        new_text: fixed_content,
+                                    };
+
+                                    return Ok(Some(vec![edit]));
+                                }
+                            }
+                            Err(e) => {
+                                log::error!("Failed to apply fixes: {e}");
+                            }
+                        }
+                    }
+
+                    // No fixes available or applied
+                    Ok(None)
+                }
+                Err(e) => {
+                    log::error!("Failed to format document: {e}");
+                    Ok(None)
+                }
+            }
+        } else {
+            Ok(None)
+        }
+    }
+
     async fn diagnostic(&self, params: DocumentDiagnosticParams) -> JsonRpcResult<DocumentDiagnosticReportResult> {
         let uri = params.text_document.uri;
 
@@ -687,4 +868,43 @@ mod tests {
         assert!(config.enable_auto_fix);
         assert_eq!(config.config_path, Some("/custom/path.toml".to_string()));
     }
+
+    #[tokio::test]
+    async fn test_document_formatting() {
+        let server = create_test_server();
+        let uri = Url::parse("file:///test.md").unwrap();
+        let text = "# Test\n\nThis is a test  \nWith trailing spaces  ";
+
+        // Store document
+        server.documents.write().await.insert(uri.clone(), text.to_string());
+
+        // Create formatting params
+        let params = DocumentFormattingParams {
+            text_document: TextDocumentIdentifier { uri: uri.clone() },
+            options: FormattingOptions {
+                tab_size: 4,
+                insert_spaces: true,
+                properties: HashMap::new(),
+                trim_trailing_whitespace: Some(true),
+                insert_final_newline: Some(true),
+                trim_final_newlines: Some(true),
+            },
+            work_done_progress_params: WorkDoneProgressParams::default(),
+        };
+
+        // Call formatting
+        let result = server.formatting(params).await.unwrap();
+
+        // Should return text edits that fix the trailing spaces
+        assert!(result.is_some());
+        let edits = result.unwrap();
+        assert!(!edits.is_empty());
+
+        // The new text should have trailing spaces removed
+        let edit = &edits[0];
+        // The formatted text should have the trailing spaces removed from the middle line
+        // and a final newline added
+        let expected = "# Test\n\nThis is a test  \nWith trailing spaces\n";
+        assert_eq!(edit.new_text, expected);
+    }
 }
