@@ -243,12 +243,11 @@ impl PerformanceBenchmark {
             // Try to read from /proc/self/status
             if let Ok(status) = std::fs::read_to_string("/proc/self/status") {
                 for line in status.lines() {
-                    if line.starts_with("VmRSS:") {
-                        if let Some(kb_str) = line.split_whitespace().nth(1) {
-                            if let Ok(kb) = kb_str.parse::<f64>() {
-                                return Some(kb / 1024.0); // Convert KB to MB
-                            }
-                        }
+                    if line.starts_with("VmRSS:")
+                        && let Some(kb_str) = line.split_whitespace().nth(1)
+                        && let Ok(kb) = kb_str.parse::<f64>()
+                    {
+                        return Some(kb / 1024.0); // Convert KB to MB
                     }
                 }
             }
@@ -267,7 +266,7 @@ impl PerformanceBenchmark {
 
     /// Benchmark a single rule with given content
     pub fn benchmark_rule(&self, rule: &dyn Rule, content: &str) -> RulePerformanceResult {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let content_size = content.len();
         let lines_count = content.lines().count();
 
@@ -317,7 +316,7 @@ impl PerformanceBenchmark {
 
     /// Benchmark all rules with given content
     pub fn benchmark_all_rules(&self, content: &str) -> AggregatePerformanceResult {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let content_size = content.len();
         let lines_count = content.lines().count();
         let mut rule_results = Vec::new();
