@@ -63,23 +63,29 @@ impl ListUtils {
         }
 
         // Quick literal check for common list markers
-        let first_char = trimmed.chars().next().unwrap();
+        let Some(first_char) = trimmed.chars().next() else {
+            return false;
+        };
         match first_char {
             '*' | '+' | '-' => {
                 if trimmed.len() > 1 {
-                    let second_char = trimmed.chars().nth(1).unwrap();
-                    return second_char.is_whitespace();
+                    let mut chars = trimmed.chars();
+                    chars.next(); // Skip first char
+                    if let Some(second_char) = chars.next() {
+                        return second_char.is_whitespace();
+                    }
                 }
                 false
             }
             '0'..='9' => {
                 // Check for ordered list pattern using a literal search first
                 let dot_pos = trimmed.find('.');
-                if let Some(pos) = dot_pos {
-                    if pos > 0 && pos < trimmed.len() - 1 {
-                        let after_dot = &trimmed[pos + 1..];
-                        return after_dot.starts_with(' ');
-                    }
+                if let Some(pos) = dot_pos
+                    && pos > 0
+                    && pos < trimmed.len() - 1
+                {
+                    let after_dot = &trimmed[pos + 1..];
+                    return after_dot.starts_with(' ');
                 }
                 false
             }
@@ -100,9 +106,13 @@ impl ListUtils {
         }
 
         // Quick literal check for unordered list markers
-        let first_char = trimmed.chars().next().unwrap();
-        if (first_char == '*' || first_char == '+' || first_char == '-') && trimmed.len() > 1 {
-            let second_char = trimmed.chars().nth(1).unwrap();
+        let Some(first_char) = trimmed.chars().next() else {
+            return false;
+        };
+        if (first_char == '*' || first_char == '+' || first_char == '-')
+            && trimmed.len() > 1
+            && let Some(second_char) = trimmed.chars().nth(1)
+        {
             return second_char.is_whitespace();
         }
 
@@ -117,17 +127,26 @@ impl ListUtils {
         }
 
         let trimmed = line.trim_start();
-        if trimmed.is_empty() || !trimmed.chars().next().unwrap().is_ascii_digit() {
+        if trimmed.is_empty() {
+            return false;
+        }
+
+        let Some(first_char) = trimmed.chars().next() else {
+            return false;
+        };
+
+        if !first_char.is_ascii_digit() {
             return false;
         }
 
         // Check for ordered list pattern using a literal search
         let dot_pos = trimmed.find('.');
-        if let Some(pos) = dot_pos {
-            if pos > 0 && pos < trimmed.len() - 1 {
-                let after_dot = &trimmed[pos + 1..];
-                return after_dot.starts_with(' ');
-            }
+        if let Some(pos) = dot_pos
+            && pos > 0
+            && pos < trimmed.len() - 1
+        {
+            let after_dot = &trimmed[pos + 1..];
+            return after_dot.starts_with(' ');
         }
 
         false
