@@ -5,7 +5,7 @@ use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severi
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
 use crate::utils::element_cache::{ElementCache, ListMarkerType};
-use crate::utils::regex_cache::{CODE_FENCE_REGEX, UNORDERED_LIST_MARKER_REGEX};
+use crate::utils::regex_cache::UNORDERED_LIST_MARKER_REGEX;
 use toml;
 
 mod md007_config;
@@ -23,6 +23,7 @@ impl MD007ULIndent {
                 indent,
                 start_indented: false,
                 start_indent: 2,
+                style: md007_config::IndentStyle::TextAligned,
             },
         }
     }
@@ -69,30 +70,6 @@ impl MD007ULIndent {
         }
         (false, None)
     }
-
-    #[allow(dead_code)]
-    fn is_in_code_block(content: &str, line_idx: usize) -> bool {
-        // Use centralized code fence pattern
-
-        let lines: Vec<&str> = content.lines().collect();
-        let mut in_code_block = false;
-
-        for (i, line) in lines.iter().enumerate() {
-            if i > line_idx {
-                break;
-            }
-
-            if CODE_FENCE_REGEX.is_match(line.trim_start()) {
-                in_code_block = !in_code_block;
-            }
-
-            if i == line_idx {
-                return in_code_block;
-            }
-        }
-
-        false
-    }
 }
 
 impl Rule for MD007ULIndent {
@@ -139,22 +116,31 @@ impl Rule for MD007ULIndent {
                 let expected_indent = if self.config.start_indented {
                     self.config.start_indent + (item.nesting_level * self.config.indent)
                 } else {
-                    // For any nested item, check if it should align with parent's text content
-                    if item.nesting_level > 0 {
-                        let (has_parent, expected_pos) = self.get_parent_info(ctx, item.line_number, item.indentation);
-                        if has_parent {
-                            if let Some(pos) = expected_pos {
-                                // Align with parent's text content
-                                pos
-                            } else {
-                                // Fallback to standard indentation
-                                item.nesting_level * self.config.indent
-                            }
-                        } else {
+                    match self.config.style {
+                        md007_config::IndentStyle::Fixed => {
+                            // Fixed style: simple multiples of indent
                             item.nesting_level * self.config.indent
                         }
-                    } else {
-                        item.nesting_level * self.config.indent
+                        md007_config::IndentStyle::TextAligned => {
+                            // Text-aligned style: align with parent's text content
+                            if item.nesting_level > 0 {
+                                let (has_parent, expected_pos) =
+                                    self.get_parent_info(ctx, item.line_number, item.indentation);
+                                if has_parent {
+                                    if let Some(pos) = expected_pos {
+                                        // Align with parent's text content
+                                        pos
+                                    } else {
+                                        // Fallback to standard indentation
+                                        item.nesting_level * self.config.indent
+                                    }
+                                } else {
+                                    item.nesting_level * self.config.indent
+                                }
+                            } else {
+                                item.nesting_level * self.config.indent
+                            }
+                        }
                     }
                 };
 
@@ -251,22 +237,31 @@ impl Rule for MD007ULIndent {
                 let expected_indent = if self.config.start_indented {
                     self.config.start_indent + (item.nesting_level * self.config.indent)
                 } else {
-                    // For any nested item, check if it should align with parent's text content
-                    if item.nesting_level > 0 {
-                        let (has_parent, expected_pos) = self.get_parent_info(ctx, item.line_number, item.indentation);
-                        if has_parent {
-                            if let Some(pos) = expected_pos {
-                                // Align with parent's text content
-                                pos
-                            } else {
-                                // Fallback to standard indentation
-                                item.nesting_level * self.config.indent
-                            }
-                        } else {
+                    match self.config.style {
+                        md007_config::IndentStyle::Fixed => {
+                            // Fixed style: simple multiples of indent
                             item.nesting_level * self.config.indent
                         }
-                    } else {
-                        item.nesting_level * self.config.indent
+                        md007_config::IndentStyle::TextAligned => {
+                            // Text-aligned style: align with parent's text content
+                            if item.nesting_level > 0 {
+                                let (has_parent, expected_pos) =
+                                    self.get_parent_info(ctx, item.line_number, item.indentation);
+                                if has_parent {
+                                    if let Some(pos) = expected_pos {
+                                        // Align with parent's text content
+                                        pos
+                                    } else {
+                                        // Fallback to standard indentation
+                                        item.nesting_level * self.config.indent
+                                    }
+                                } else {
+                                    item.nesting_level * self.config.indent
+                                }
+                            } else {
+                                item.nesting_level * self.config.indent
+                            }
+                        }
                     }
                 };
 
@@ -419,7 +414,7 @@ mod tests {
     fn test_valid_list_indent() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -432,7 +427,7 @@ mod tests {
     fn test_invalid_list_indent() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n   * Item 2\n      * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 2);
@@ -445,7 +440,7 @@ mod tests {
     fn test_mixed_indentation() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n  * Item 2\n   * Item 3\n  * Item 4";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 3);
@@ -456,7 +451,7 @@ mod tests {
     fn test_fix_indentation() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n   * Item 2\n      * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.fix(&ctx).unwrap();
         // With dynamic alignment:
         // Item 2 aligns with Item 1's text (2 spaces)
@@ -475,7 +470,7 @@ repos:
     hooks:
     -   id: rumdl-check
 ```"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -487,7 +482,7 @@ repos:
     fn test_blockquoted_list_indent() {
         let rule = MD007ULIndent::default();
         let content = "> * Item 1\n>   * Item 2\n>     * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -499,7 +494,7 @@ repos:
     fn test_blockquoted_list_invalid_indent() {
         let rule = MD007ULIndent::default();
         let content = "> * Item 1\n>    * Item 2\n>       * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -514,7 +509,7 @@ repos:
     fn test_nested_blockquote_list_indent() {
         let rule = MD007ULIndent::default();
         let content = "> > * Item 1\n> >   * Item 2\n> >     * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -526,7 +521,7 @@ repos:
     fn test_blockquote_list_with_code_block() {
         let rule = MD007ULIndent::default();
         let content = "> * Item 1\n>   * Item 2\n>   ```\n>   code\n>   ```\n>   * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -548,7 +543,7 @@ repos:
         ];
 
         for content in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert!(
                 result.is_empty(),
@@ -569,7 +564,7 @@ repos:
         ];
 
         for (content, expected_warnings, line) in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert_eq!(
                 result.len(),
@@ -593,7 +588,7 @@ repos:
         ];
 
         for (content, expected_warnings, line) in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert_eq!(
                 result.len(),
@@ -610,7 +605,7 @@ repos:
     fn test_custom_indent_2_spaces() {
         let rule = MD007ULIndent::new(2); // Default
         let content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -621,7 +616,7 @@ repos:
         let rule = MD007ULIndent::new(3);
 
         let content = "* Item 1\n   * Item 2\n      * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With dynamic alignment, Item 2 should align with Item 1's text (2 spaces)
         // and Item 3 should align with Item 2's text (4 spaces), not fixed increments
@@ -630,7 +625,7 @@ repos:
         // Test that dynamic alignment works correctly
         // Item 3 should align with Item 2's text content (4 spaces)
         let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(correct_content);
+        let ctx = LintContext::new(correct_content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -640,7 +635,7 @@ repos:
         // Test dynamic alignment behavior (default start_indented=false)
         let rule = MD007ULIndent::new(4);
         let content = "* Item 1\n    * Item 2\n        * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With dynamic alignment, should expect 2 spaces and 6 spaces, not 4 and 8
         assert!(!result.is_empty()); // Should have warnings due to alignment
@@ -648,7 +643,7 @@ repos:
         // Test correct dynamic alignment
         // Item 3 should align with Item 2's text content (4 spaces)
         let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(correct_content);
+        let ctx = LintContext::new(correct_content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -659,7 +654,7 @@ repos:
 
         // Single tab
         let content = "* Item 1\n\t* Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Tab indentation should trigger warning");
 
@@ -669,14 +664,14 @@ repos:
 
         // Multiple tabs
         let content_multi = "* Item 1\n\t* Item 2\n\t\t* Item 3";
-        let ctx = LintContext::new(content_multi);
+        let ctx = LintContext::new(content_multi, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2 at correct position
         assert_eq!(fixed, "* Item 1\n  * Item 2\n   * Item 3");
 
         // Mixed tabs and spaces
         let content_mixed = "* Item 1\n \t* Item 2\n\t * Item 3";
-        let ctx = LintContext::new(content_mixed);
+        let ctx = LintContext::new(content_mixed, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2 at correct position
         assert_eq!(fixed, "* Item 1\n  * Item 2\n    * Item 3");
@@ -695,7 +690,7 @@ repos:
   1. Ordered sub-item
   * Unordered sub-item"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 0, "All unordered list indentation should be correct");
 
@@ -716,7 +711,7 @@ repos:
 + Plus
   + Nested plus"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -731,7 +726,7 @@ repos:
 + Plus
     + Wrong plus"#;
 
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 3, "All marker types should be checked for indentation");
     }
@@ -740,7 +735,7 @@ repos:
     fn test_empty_list_items() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n* \n  * Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -757,7 +752,7 @@ repos:
   ```
   * Item 2
     * Item 3"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -772,7 +767,7 @@ tags:
 ---
 * Item 1
   * Item 2"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Lists in YAML front matter should be ignored");
     }
@@ -781,7 +776,7 @@ tags:
     fn test_fix_preserves_content() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1 with **bold** and *italic*\n   * Item 2 with `code`\n     * Item 3 with [link](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2's text (2 + 2 + 1 = 5 spaces)
         let expected = "* Item 1 with **bold** and *italic*\n  * Item 2 with `code`\n     * Item 3 with [link](url)";
@@ -794,6 +789,7 @@ tags:
             start_indented: true,
             start_indent: 4,
             indent: 2,
+            style: md007_config::IndentStyle::TextAligned,
         };
         let rule = MD007ULIndent::from_config_struct(config);
 
@@ -802,13 +798,13 @@ tags:
         // Level 1: 6 spaces (start_indent + indent = 4 + 2)
         // Level 2: 8 spaces (start_indent + 2*indent = 4 + 4)
         let content = "    * Item 1\n      * Item 2\n        * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings with start_indented config");
 
         // Wrong first level indentation
         let wrong_content = "  * Item 1\n    * Item 2";
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 1);
@@ -827,7 +823,7 @@ tags:
 
         // When start_indented is false, first level items at any indentation are allowed
         let content = "   * Item 1"; // First level at 3 spaces
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -836,7 +832,7 @@ tags:
 
         // Multiple first level items at different indentations should all be allowed
         let content = "* Item 1\n  * Item 2\n    * Item 3"; // All at level 0 (different indents)
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -853,7 +849,7 @@ tags:
       * L4
         * L5
           * L6"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
@@ -864,7 +860,7 @@ tags:
       * L4
          * L5
             * L6"#;
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Deep nesting errors should be detected");
     }
@@ -879,7 +875,7 @@ tags:
 
 2. **Oracle Unified Directory (OUD)**
    - Extended user directory services";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should have no warnings - 3 spaces is correct for bullets under numbered items
         assert!(
@@ -894,7 +890,7 @@ tags:
         let content = "\
 1. **Active Directory/LDAP**
   - Wrong: only 2 spaces";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should flag incorrect indentation
         assert_eq!(
@@ -916,7 +912,7 @@ tags:
 * Top level
   * Nested bullet (2 spaces is correct)
     * Deeply nested (4 spaces)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should have no warnings - standard bullet nesting still uses 2-space increments
         assert!(
