@@ -9,15 +9,15 @@ pub struct MD013Config {
     #[serde(default = "default_line_length")]
     pub line_length: usize,
 
-    /// Apply rule to code blocks (default: true)
+    /// Check code blocks for line length (default: true)
     #[serde(default = "default_code_blocks")]
     pub code_blocks: bool,
 
-    /// Apply rule to tables (default: true)
+    /// Check tables for line length (default: true)
     #[serde(default = "default_tables")]
     pub tables: bool,
 
-    /// Apply rule to headings (default: true)
+    /// Check headings for line length (default: true)
     #[serde(default = "default_headings")]
     pub headings: bool,
 
@@ -25,21 +25,9 @@ pub struct MD013Config {
     #[serde(default)]
     pub strict: bool,
 
-    /// Maximum line length for headings (default: None, uses line_length)
-    #[serde(default)]
-    pub heading_line_length: Option<usize>,
-
-    /// Maximum line length for code blocks (default: None, uses line_length)
-    #[serde(default)]
-    pub code_block_line_length: Option<usize>,
-
-    /// Stern mode - stricter checking without exceptions (default: false)
-    #[serde(default)]
-    pub stern: bool,
-
     /// Enable text reflow to wrap long lines (default: false)
-    #[serde(default)]
-    pub enable_reflow: bool,
+    #[serde(default, rename = "reflow", alias = "enable_reflow")]
+    pub reflow: bool,
 }
 
 fn default_line_length() -> usize {
@@ -66,10 +54,7 @@ impl Default for MD013Config {
             tables: default_tables(),
             headings: default_headings(),
             strict: false,
-            heading_line_length: None,
-            code_block_line_length: None,
-            stern: false,
-            enable_reflow: false,
+            reflow: false,
         }
     }
 }
