@@ -308,13 +308,13 @@ mod tests {
 
         // Test with correct space
         let content = "# Heading 1\n## Heading 2\n### Heading 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test with missing space
         let content = "#Heading 1\n## Heading 2\n###Heading 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2); // Should flag the two headings with missing spaces
         assert_eq!(result[0].line, 1);
@@ -363,7 +363,7 @@ This should NOT be detected (fenced code block).
 This should be detected.
 "#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should detect malformed headings but ignore code blocks
@@ -384,7 +384,7 @@ This is a test.
 ###Background
 More content."#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = r#"## Introduction
@@ -411,7 +411,7 @@ More content."#;
 #### Proper with space
 "#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should only detect the malformed ones
