@@ -61,10 +61,10 @@ impl Rule for MD030ListMarkerSpace {
             let line_num = i + 1;
 
             // Skip if in code block
-            if let Some(line_info) = ctx.line_info(line_num) {
-                if line_info.in_code_block {
-                    continue;
-                }
+            if let Some(line_info) = ctx.line_info(line_num)
+                && line_info.in_code_block
+            {
+                continue;
             }
             // Skip indented code blocks (4+ spaces or tab)
             if line.starts_with("    ") || line.starts_with("\t") {
@@ -81,69 +81,71 @@ impl Rule for MD030ListMarkerSpace {
                 continue;
             }
             // Use pre-computed list item information
-            if let Some(line_info) = ctx.line_info(line_num) {
-                if let Some(list_info) = &line_info.list_item {
-                    let list_type = if list_info.is_ordered {
-                        ListType::Ordered
-                    } else {
-                        ListType::Unordered
-                    };
+            if let Some(line_info) = ctx.line_info(line_num)
+                && let Some(list_info) = &line_info.list_item
+            {
+                let list_type = if list_info.is_ordered {
+                    ListType::Ordered
+                } else {
+                    ListType::Unordered
+                };
 
-                    // Calculate actual spacing after marker
-                    let marker_end = list_info.marker_column + list_info.marker.len();
-                    let actual_spaces = list_info.content_column.saturating_sub(marker_end);
+                // Calculate actual spacing after marker
+                let marker_end = list_info.marker_column + list_info.marker.len();
+                let actual_spaces = list_info.content_column.saturating_sub(marker_end);
 
-                    let expected_spaces = self.get_expected_spaces(list_type, false);
+                // Determine if this is a multi-line list item
+                let is_multi_line = self.is_multi_line_list_item(ctx, line_num);
+                let expected_spaces = self.get_expected_spaces(list_type, is_multi_line);
 
-                    // Check for tabs in the spacing
-                    let line_content = &line[list_info.marker_column..];
-                    let spacing_content = if line_content.len() > list_info.marker.len() {
-                        let after_marker_start = list_info.marker.len();
-                        let after_marker_end = after_marker_start + actual_spaces;
-                        &line_content[after_marker_start..after_marker_end.min(line_content.len())]
-                    } else {
-                        ""
-                    };
-                    let has_tabs = spacing_content.contains('\t');
+                // Check for tabs in the spacing
+                let line_content = &line[list_info.marker_column..];
+                let spacing_content = if line_content.len() > list_info.marker.len() {
+                    let after_marker_start = list_info.marker.len();
+                    let after_marker_end = after_marker_start + actual_spaces;
+                    &line_content[after_marker_start..after_marker_end.min(line_content.len())]
+                } else {
+                    ""
+                };
+                let has_tabs = spacing_content.contains('\t');
 
-                    // Check if spacing is incorrect or contains tabs
-                    if actual_spaces != expected_spaces || has_tabs {
-                        // Calculate precise character range for the problematic spacing
-                        let whitespace_start_pos = marker_end;
-                        let whitespace_len = actual_spaces;
+                // Check if spacing is incorrect or contains tabs
+                if actual_spaces != expected_spaces || has_tabs {
+                    // Calculate precise character range for the problematic spacing
+                    let whitespace_start_pos = marker_end;
+                    let whitespace_len = actual_spaces;
 
-                        // Calculate the range that needs to be replaced (the entire whitespace after marker)
-                        let (start_line, start_col, end_line, end_col) =
-                            calculate_match_range(line_num, line, whitespace_start_pos, whitespace_len);
+                    // Calculate the range that needs to be replaced (the entire whitespace after marker)
+                    let (start_line, start_col, end_line, end_col) =
+                        calculate_match_range(line_num, line, whitespace_start_pos, whitespace_len);
 
-                        // Generate the correct replacement text (just the correct spacing)
-                        let correct_spaces = " ".repeat(expected_spaces);
+                    // Generate the correct replacement text (just the correct spacing)
+                    let correct_spaces = " ".repeat(expected_spaces);
 
-                        // Calculate byte positions for the fix range
-                        let line_start_byte = ctx.line_offsets.get(line_num - 1).copied().unwrap_or(0);
-                        let whitespace_start_byte = line_start_byte + whitespace_start_pos;
-                        let whitespace_end_byte = whitespace_start_byte + whitespace_len;
+                    // Calculate byte positions for the fix range
+                    let line_start_byte = ctx.line_offsets.get(line_num - 1).copied().unwrap_or(0);
+                    let whitespace_start_byte = line_start_byte + whitespace_start_pos;
+                    let whitespace_end_byte = whitespace_start_byte + whitespace_len;
 
-                        let fix = Some(crate::rule::Fix {
-                            range: whitespace_start_byte..whitespace_end_byte,
-                            replacement: correct_spaces,
-                        });
+                    let fix = Some(crate::rule::Fix {
+                        range: whitespace_start_byte..whitespace_end_byte,
+                        replacement: correct_spaces,
+                    });
 
-                        // Generate appropriate message
-                        let message =
-                            format!("Spaces after list markers (Expected: {expected_spaces}; Actual: {actual_spaces})");
+                    // Generate appropriate message
+                    let message =
+                        format!("Spaces after list markers (Expected: {expected_spaces}; Actual: {actual_spaces})");
 
-                        warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
-                            severity: Severity::Warning,
-                            line: start_line,
-                            column: start_col,
-                            end_line,
-                            end_column: end_col,
-                            message,
-                            fix,
-                        });
-                    }
+                    warnings.push(LintWarning {
+                        rule_name: Some(self.name()),
+                        severity: Severity::Warning,
+                        line: start_line,
+                        column: start_col,
+                        end_line,
+                        end_column: end_col,
+                        message,
+                        fix,
+                    });
                 }
             }
         }
@@ -201,11 +203,11 @@ impl Rule for MD030ListMarkerSpace {
             let line_num = line_idx + 1;
 
             // Skip if in code block
-            if let Some(line_info) = ctx.line_info(line_num) {
-                if line_info.in_code_block {
-                    result_lines.push(line.to_string());
-                    continue;
-                }
+            if let Some(line_info) = ctx.line_info(line_num)
+                && line_info.in_code_block
+            {
+                result_lines.push(line.to_string());
+                continue;
             }
 
             // Skip if in front matter
@@ -227,7 +229,8 @@ impl Rule for MD030ListMarkerSpace {
             }
 
             // Try to fix list marker spacing
-            if let Some(fixed_line) = self.try_fix_list_marker_spacing(line) {
+            let is_multi_line = self.is_multi_line_list_item(ctx, line_num);
+            if let Some(fixed_line) = self.try_fix_list_marker_spacing_with_context(line, is_multi_line) {
                 result_lines.push(fixed_line);
             } else {
                 result_lines.push(line.to_string());
@@ -245,8 +248,55 @@ impl Rule for MD030ListMarkerSpace {
 }
 
 impl MD030ListMarkerSpace {
-    /// Fix list marker spacing - handles tabs, multiple spaces, and mixed whitespace
-    fn try_fix_list_marker_spacing(&self, line: &str) -> Option<String> {
+    /// Check if a list item is multi-line (spans multiple lines or contains nested content)
+    fn is_multi_line_list_item(&self, ctx: &crate::lint_context::LintContext, line_num: usize) -> bool {
+        // Get the current list item info
+        let current_line_info = match ctx.line_info(line_num) {
+            Some(info) if info.list_item.is_some() => info,
+            _ => return false,
+        };
+
+        let current_list = current_line_info.list_item.as_ref().unwrap();
+        let lines: Vec<&str> = ctx.content.lines().collect();
+
+        // Check subsequent lines to see if they are continuation of this list item
+        for next_line_num in (line_num + 1)..=lines.len() {
+            if let Some(next_line_info) = ctx.line_info(next_line_num) {
+                // If we encounter another list item at the same or higher level, this item is done
+                if let Some(next_list) = &next_line_info.list_item {
+                    if next_list.marker_column <= current_list.marker_column {
+                        break; // Found the next list item at same/higher level
+                    }
+                    // If there's a nested list item, this is multi-line
+                    return true;
+                }
+
+                // If we encounter a non-empty line that's not indented enough to be part of this list item,
+                // this list item is done
+                let line_content = lines.get(next_line_num - 1).unwrap_or(&"");
+                if !line_content.trim().is_empty() {
+                    let expected_continuation_indent = current_list.content_column;
+                    let actual_indent = line_content.len() - line_content.trim_start().len();
+
+                    if actual_indent < expected_continuation_indent {
+                        break; // Line is not indented enough to be part of this list item
+                    }
+
+                    // If we find a continuation line, this is multi-line
+                    if actual_indent >= expected_continuation_indent {
+                        return true;
+                    }
+                }
+
+                // Empty lines don't affect the multi-line status by themselves
+            }
+        }
+
+        false
+    }
+
+    /// Fix list marker spacing with context - handles tabs, multiple spaces, and mixed whitespace
+    fn try_fix_list_marker_spacing_with_context(&self, line: &str, is_multi_line: bool) -> Option<String> {
         let trimmed = line.trim_start();
         let indent = &line[..line.len() - trimmed.len()];
 
@@ -256,12 +306,16 @@ impl MD030ListMarkerSpace {
                 // Fix if there are tabs, multiple spaces, or mixed whitespace
                 if after_marker.starts_with('\t')
                     || after_marker.starts_with("  ")
-                    || (after_marker.starts_with(' ') && after_marker.chars().nth(1) == Some('\t'))
+                    || (after_marker.starts_with(' ') && after_marker.as_bytes().get(1) == Some(&b'\t'))
                 {
                     let content = after_marker.trim_start();
                     if !content.is_empty() {
-                        // Use the configured number of spaces for unordered lists
-                        let spaces = " ".repeat(self.config.ul_single);
+                        // Use appropriate configuration based on whether it's multi-line
+                        let spaces = if is_multi_line {
+                            " ".repeat(self.config.ul_multi)
+                        } else {
+                            " ".repeat(self.config.ul_single)
+                        };
                         return Some(format!("{indent}{marker}{spaces}{content}"));
                     }
                 }
@@ -277,12 +331,16 @@ impl MD030ListMarkerSpace {
                 // Fix if there are tabs, multiple spaces, or mixed whitespace
                 if after_dot.starts_with('\t')
                     || after_dot.starts_with("  ")
-                    || (after_dot.starts_with(' ') && after_dot.chars().nth(1) == Some('\t'))
+                    || (after_dot.starts_with(' ') && after_dot.as_bytes().get(1) == Some(&b'\t'))
                 {
                     let content = after_dot.trim_start();
                     if !content.is_empty() {
-                        // Use the configured number of spaces for ordered lists
-                        let spaces = " ".repeat(self.config.ol_single);
+                        // Use appropriate configuration based on whether it's multi-line
+                        let spaces = if is_multi_line {
+                            " ".repeat(self.config.ol_multi)
+                        } else {
+                            " ".repeat(self.config.ol_single)
+                        };
                         return Some(format!("{indent}{before_dot}.{spaces}{content}"));
                     }
                 }
@@ -292,6 +350,8 @@ impl MD030ListMarkerSpace {
         None
     }
 
+    /// Fix list marker spacing - handles tabs, multiple spaces, and mixed whitespace
+    /// (Legacy method for backward compatibility - defaults to single-line behavior)
     /// Check if a line is part of an indented code block (4+ spaces with blank line before)
     fn is_indented_code_block(&self, line: &str, line_idx: usize, lines: &[&str]) -> bool {
         // Must start with 4+ spaces or tab
@@ -359,7 +419,7 @@ mod tests {
         let rule = MD030ListMarkerSpace::default();
         let content = "* Item 1\n* Item 2\n  * Nested item\n1. Ordered item";
         let structure = DocumentStructure::new(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         assert!(
             result.is_empty(),
@@ -367,7 +427,7 @@ mod tests {
         );
         let content = "*  Item 1 (too many spaces)\n* Item 2\n1.   Ordered item (too many spaces)";
         let structure = DocumentStructure::new(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         // Expect warnings for lines with too many spaces after the marker
         assert_eq!(
