@@ -111,6 +111,7 @@ impl MD032BlanksAroundLists {
         ctx: &crate::lint_context::LintContext,
         structure: &DocumentStructure,
         prev_line_num: usize,
+        current_line_num: usize,
     ) -> bool {
         let trimmed_prev = prev_line.trim();
 
@@ -119,6 +120,11 @@ impl MD032BlanksAroundLists {
             return true;
         }
 
+        // Always allow nested lists (lists indented within other list items)
+        if self.is_nested_list(ctx, prev_line_num, current_line_num) {
+            return false;
+        }
+
         // Allow lists after headings if configured
         if self.allow_after_headings && self.is_heading_line_from_context(ctx, prev_line_num - 1) {
             return false;
@@ -142,6 +148,30 @@ impl MD032BlanksAroundLists {
         }
     }
 
+    /// Check if the current list is nested within another list item
+    fn is_nested_list(
+        &self,
+        ctx: &crate::lint_context::LintContext,
+        prev_line_num: usize,    // 1-indexed
+        current_line_num: usize, // 1-indexed
+    ) -> bool {
+        // Check if current line is indented (typical for nested lists)
+        if current_line_num > 0 && current_line_num - 1 < ctx.lines.len() {
+            let current_line = &ctx.lines[current_line_num - 1];
+            if current_line.indent >= 2 {
+                // Check if previous line is a list item or list content
+                if prev_line_num > 0 && prev_line_num - 1 < ctx.lines.len() {
+                    let prev_line = &ctx.lines[prev_line_num - 1];
+                    // Previous line is a list item or indented content
+                    if prev_line.list_item.is_some() || prev_line.indent >= 2 {
+                        return true;
+                    }
+                }
+            }
+        }
+        false
+    }
+
     // Convert centralized list blocks to the format expected by perform_checks
     fn convert_list_blocks(&self, ctx: &crate::lint_context::LintContext) -> Vec<(usize, usize, String)> {
         let mut blocks: Vec<(usize, usize, String)> = Vec::new();
@@ -291,8 +321,13 @@ impl MD032BlanksAroundLists {
 
                 // Only require blank lines for content in the same context (same blockquote level)
                 // and when the context actually requires it
-                let should_require =
-                    self.should_require_blank_line_before(prev_line_str, ctx, structure, prev_line_actual_idx_1);
+                let should_require = self.should_require_blank_line_before(
+                    prev_line_str,
+                    ctx,
+                    structure,
+                    prev_line_actual_idx_1,
+                    start_line,
+                );
                 if !is_prev_excluded && !prev_is_blank && prefixes_match && should_require {
                     // Calculate precise character range for the entire list line that needs a blank line before it
                     let (start_line, start_col, end_line, end_col) =
@@ -488,6 +523,7 @@ impl MD032BlanksAroundLists {
                     ctx,
                     structure,
                     prev_line_actual_idx_1,
+                    start_line,
                 );
                 if !is_prev_excluded
                     && !is_blank_in_context(lines[prev_line_actual_idx_0])
@@ -529,10 +565,10 @@ impl MD032BlanksAroundLists {
         let mut result_lines: Vec<String> = Vec::with_capacity(num_lines + insertions.len());
         for (i, line) in lines.iter().enumerate() {
             let current_line_num = i + 1;
-            if let Some(prefix_to_insert) = insertions.get(&current_line_num) {
-                if result_lines.is_empty() || result_lines.last().unwrap() != prefix_to_insert {
-                    result_lines.push(prefix_to_insert.clone());
-                }
+            if let Some(prefix_to_insert) = insertions.get(&current_line_num)
+                && (result_lines.is_empty() || result_lines.last().unwrap() != prefix_to_insert)
+            {
+                result_lines.push(prefix_to_insert.clone());
             }
             result_lines.push(line.to_string());
         }
@@ -594,13 +630,13 @@ mod tests {
 
     fn lint(content: &str) -> Vec<LintWarning> {
         let rule = MD032BlanksAroundLists::default();
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.check(&ctx).expect("Lint check failed")
     }
 
     fn fix(content: &str) -> String {
         let rule = MD032BlanksAroundLists::default();
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.fix(&ctx).expect("Lint fix failed")
     }
 
