@@ -5,6 +5,7 @@
 
 use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
+use crate::utils::kramdown_utils::{is_kramdown_block_attribute, is_kramdown_extension};
 use crate::utils::range_utils::calculate_html_tag_range;
 use crate::utils::regex_cache::*;
 use lazy_static::lazy_static;
@@ -144,6 +145,14 @@ impl MD033NoInlineHtml {
             && content.split('@').all(|part| !part.is_empty())
     }
 
+    // Check if a tag has the markdown attribute (MkDocs/Material for MkDocs)
+    #[inline]
+    fn has_markdown_attribute(&self, tag: &str) -> bool {
+        // Check for various forms of markdown attribute
+        // Examples: <div markdown>, <div markdown="1">, <div class="result" markdown>
+        tag.contains(" markdown>") || tag.contains(" markdown=") || tag.contains(" markdown ")
+    }
+
     // Check if a tag is actually a URL in angle brackets
     #[inline]
     fn is_url_in_angle_brackets(&self, tag: &str) -> bool {
@@ -157,7 +166,14 @@ impl MD033NoInlineHtml {
     }
 
     /// Find HTML tags that span multiple lines
-    fn find_multiline_html_tags(&self, content: &str, structure: &DocumentStructure, warnings: &mut Vec<LintWarning>) {
+    fn find_multiline_html_tags(
+        &self,
+        ctx: &crate::lint_context::LintContext,
+        content: &str,
+        structure: &DocumentStructure,
+        nomarkdown_ranges: &[(usize, usize)],
+        warnings: &mut Vec<LintWarning>,
+    ) {
         // Early return: if content has no incomplete tags at line ends, skip processing
         if !content.contains('<') || !content.lines().any(|line| line.trim_end().ends_with('<')) {
             return;
@@ -178,6 +194,14 @@ impl MD033NoInlineHtml {
                 continue;
             }
 
+            // Skip lines inside nomarkdown blocks
+            if nomarkdown_ranges
+                .iter()
+                .any(|(start, end)| line_num >= *start && line_num <= *end)
+            {
+                continue;
+            }
+
             // Early return: skip lines that don't end with incomplete tags
             if !line.contains('<') {
                 continue;
@@ -215,11 +239,15 @@ impl MD033NoInlineHtml {
                         let final_tag = &complete_tag[0..=end_pos];
 
                         // Apply the same filters as single-line tags
+                        let skip_mkdocs_markdown = ctx.flavor == crate::config::MarkdownFlavor::MkDocs
+                            && self.has_markdown_attribute(final_tag);
+
                         if !self.is_html_comment(final_tag)
                             && !self.is_likely_type_annotation(final_tag)
                             && !self.is_email_address(final_tag)
                             && !self.is_url_in_angle_brackets(final_tag)
                             && !self.is_tag_allowed(final_tag)
+                            && !skip_mkdocs_markdown
                             && HTML_TAG_FINDER.is_match(final_tag)
                         {
                             // Check for duplicates (avoid flagging the same position twice)
@@ -288,7 +316,37 @@ impl Rule for MD033NoInlineHtml {
         let mut warnings = Vec::new();
         let lines: Vec<&str> = content.lines().collect();
 
-        // First pass: find single-line HTML tags
+        // Track nomarkdown and comment blocks
+        let mut in_nomarkdown = false;
+        let mut in_comment = false;
+        let mut nomarkdown_ranges: Vec<(usize, usize)> = Vec::new();
+        let mut nomarkdown_start = 0;
+        let mut comment_start = 0;
+
+        // First pass: identify nomarkdown and comment blocks
+        for (i, line) in lines.iter().enumerate() {
+            let line_num = i + 1;
+
+            // Check for nomarkdown start
+            if line.trim() == "{::nomarkdown}" {
+                in_nomarkdown = true;
+                nomarkdown_start = line_num;
+            } else if line.trim() == "{:/nomarkdown}" && in_nomarkdown {
+                in_nomarkdown = false;
+                nomarkdown_ranges.push((nomarkdown_start, line_num));
+            }
+
+            // Check for comment blocks
+            if line.trim() == "{::comment}" {
+                in_comment = true;
+                comment_start = line_num;
+            } else if line.trim() == "{:/comment}" && in_comment {
+                in_comment = false;
+                nomarkdown_ranges.push((comment_start, line_num));
+            }
+        }
+
+        // Second pass: find single-line HTML tags
         // To match markdownlint behavior, report one warning per HTML tag
         for (i, line) in lines.iter().enumerate() {
             let line_num = i + 1;
@@ -299,6 +357,24 @@ impl Rule for MD033NoInlineHtml {
             if structure.is_in_code_block(line_num) {
                 continue;
             }
+            // Skip lines that are indented code blocks (4+ spaces or tab) per CommonMark spec
+            // Even if they're not in the structure's code blocks (e.g., HTML blocks)
+            if line.starts_with("    ") || line.starts_with('\t') {
+                continue;
+            }
+
+            // Skip lines inside nomarkdown blocks
+            if nomarkdown_ranges
+                .iter()
+                .any(|(start, end)| line_num >= *start && line_num <= *end)
+            {
+                continue;
+            }
+
+            // Skip Kramdown extensions and block attributes
+            if is_kramdown_extension(line) || is_kramdown_block_attribute(line) {
+                continue;
+            }
 
             // Find all HTML tags in the line using regex
             for tag_match in HTML_TAG_FINDER.find_iter(line) {
@@ -335,6 +411,11 @@ impl Rule for MD033NoInlineHtml {
                     continue;
                 }
 
+                // Skip tags with markdown attribute in MkDocs mode
+                if ctx.flavor == crate::config::MarkdownFlavor::MkDocs && self.has_markdown_attribute(tag) {
+                    continue;
+                }
+
                 // Report each HTML tag individually (true markdownlint compatibility)
                 let (start_line, start_col, end_line, end_col) =
                     calculate_html_tag_range(line_num, line, tag_match.start(), tag_match.len());
@@ -351,8 +432,8 @@ impl Rule for MD033NoInlineHtml {
             }
         }
 
-        // Second pass: find multi-line HTML tags
-        self.find_multiline_html_tags(ctx.content, structure, &mut warnings);
+        // Third pass: find multi-line HTML tags
+        self.find_multiline_html_tags(ctx, ctx.content, structure, &nomarkdown_ranges, &mut warnings);
 
         Ok(warnings)
     }
@@ -362,6 +443,10 @@ impl Rule for MD033NoInlineHtml {
         Ok(ctx.content.to_string())
     }
 
+    fn fix_capability(&self) -> crate::rule::FixCapability {
+        crate::rule::FixCapability::Unfixable
+    }
+
     /// Get the category of this rule for selective processing
     fn category(&self) -> RuleCategory {
         RuleCategory::Html
@@ -419,7 +504,7 @@ mod tests {
     fn test_md033_basic_html() {
         let rule = MD033NoInlineHtml::default();
         let content = "<div>Some content</div>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result.len(), 2); // <div> and </div>
@@ -431,7 +516,7 @@ mod tests {
     fn test_md033_case_insensitive() {
         let rule = MD033NoInlineHtml::default();
         let content = "<DiV>Some <B>content</B></dIv>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result.len(), 4); // <DiV>, <B>, </B>, </dIv>
@@ -457,7 +542,7 @@ mod tests {
     fn test_md033_allowed_tags() {
         let rule = MD033NoInlineHtml::with_allowed(vec!["div".to_string(), "br".to_string()]);
         let content = "<div>Allowed</div><p>Not allowed</p><br/>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Only warnings for non-allowed tags (<p> and </p>, div and br are allowed)
         assert_eq!(result.len(), 2);
@@ -472,7 +557,7 @@ mod tests {
 
         // Test case-insensitivity of allowed tags
         let content2 = "<DIV>Allowed</DIV><P>Not allowed</P><BR/>";
-        let ctx2 = LintContext::new(content2);
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
         let result2 = rule.check(&ctx2).unwrap();
         assert_eq!(result2.len(), 2); // <P> and </P> flagged
         assert_eq!(
@@ -489,7 +574,7 @@ mod tests {
     fn test_md033_html_comments() {
         let rule = MD033NoInlineHtml::default();
         let content = "<!-- This is a comment --> <p>Not a comment</p>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should detect warnings for HTML tags (comments are skipped)
         assert_eq!(result.len(), 2); // <p> and </p>
@@ -507,7 +592,7 @@ mod tests {
     fn test_md033_tags_in_links() {
         let rule = MD033NoInlineHtml::default();
         let content = "[Link](http://example.com/<div>)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // The <div> in the URL should be detected as HTML (not skipped)
         assert_eq!(result.len(), 1);
@@ -517,7 +602,7 @@ mod tests {
         );
 
         let content2 = "[Link <a>text</a>](url)";
-        let ctx2 = LintContext::new(content2);
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
         let result2 = rule.check(&ctx2).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result2.len(), 2); // <a> and </a>
@@ -535,7 +620,7 @@ mod tests {
     fn test_md033_fix_escaping() {
         let rule = MD033NoInlineHtml::default();
         let content = "Text with <div> and <br/> tags.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed_content = rule.fix(&ctx).unwrap();
         // No fix for HTML tags; output should be unchanged
         assert_eq!(fixed_content, content);
@@ -545,7 +630,7 @@ mod tests {
     fn test_md033_in_code_blocks() {
         let rule = MD033NoInlineHtml::default();
         let content = "```html\n<div>Code</div>\n```\n<div>Not code</div>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result.len(), 2); // <div> and </div> outside code block
@@ -563,7 +648,7 @@ mod tests {
     fn test_md033_in_code_spans() {
         let rule = MD033NoInlineHtml::default();
         let content = "Text with `<p>in code</p>` span. <br/> Not in span.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should detect <br/> outside code span, but not tags inside code span
         assert_eq!(result.len(), 1);
