@@ -1,6 +1,7 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rules::code_block_utils::CodeBlockStyle;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
+use crate::utils::mkdocs_tabs;
 use crate::utils::range_utils::{LineIndex, calculate_line_range};
 use toml;
 
@@ -41,7 +42,7 @@ impl MD046CodeBlockStyle {
                 && (trimmed.contains(". ") || trimmed.contains(") ")))
     }
 
-    fn is_indented_code_block(&self, lines: &[&str], i: usize) -> bool {
+    fn is_indented_code_block(&self, lines: &[&str], i: usize, is_mkdocs: bool) -> bool {
         if i >= lines.len() {
             return false;
         }
@@ -58,8 +59,8 @@ impl MD046CodeBlockStyle {
             return false;
         }
 
-        // Check if this is part of a formatted text block (not a code block)
-        if self.is_part_of_formatted_text_block(lines, i) {
+        // Skip if this is MkDocs tab content
+        if is_mkdocs && self.is_in_mkdocs_tab(lines, i) {
             return false;
         }
 
@@ -69,7 +70,7 @@ impl MD046CodeBlockStyle {
         let prev_is_indented_code = i > 0
             && (lines[i - 1].starts_with("    ") || lines[i - 1].starts_with("\t"))
             && !self.is_part_of_list_structure(lines, i - 1)
-            && !self.is_part_of_formatted_text_block(lines, i - 1);
+            && !(is_mkdocs && self.is_in_mkdocs_tab(lines, i - 1));
 
         // If no blank line before and previous line is not indented code,
         // it's likely list continuation, not a code block
@@ -80,80 +81,6 @@ impl MD046CodeBlockStyle {
         true
     }
 
-    /// Check if an indented line is part of a formatted text block (like license text)
-    /// rather than a code block
-    fn is_part_of_formatted_text_block(&self, lines: &[&str], i: usize) -> bool {
-        let line = lines[i];
-        let trimmed = line.trim();
-
-        // Look for patterns that suggest this is formatted text, not code:
-
-        // 1. License/legal text patterns
-        if trimmed.contains("Copyright")
-            || trimmed.contains("License")
-            || trimmed.contains("Foundation")
-            || trimmed.contains("Certificate")
-            || trimmed.contains("Origin")
-            || trimmed.starts_with("Version ")
-            || trimmed.contains("permitted")
-            || trimmed.contains("contribution")
-            || trimmed.contains("certify")
-        {
-            return true;
-        }
-
-        // 2. Address/contact information patterns
-        if trimmed.contains("Drive")
-            || trimmed.contains("Suite")
-            || trimmed.contains("CA,")
-            || trimmed.contains("San Francisco")
-        {
-            return true;
-        }
-
-        // 3. Email signature patterns
-        if trimmed.contains("Signed-off-by:") || trimmed.contains("@") && trimmed.contains(".com") {
-            return true;
-        }
-
-        // 4. Check if this is part of a larger block of indented text
-        // that looks like formatted prose rather than code
-        let mut consecutive_indented_lines = 0;
-        let mut has_prose_content = false;
-
-        // Look at surrounding lines to see if this is part of a prose block
-        let start = i.saturating_sub(5);
-        let end = if i + 5 < lines.len() { i + 5 } else { lines.len() };
-
-        for check_line in lines.iter().take(end).skip(start) {
-            if check_line.starts_with("    ") || check_line.starts_with("\t") {
-                consecutive_indented_lines += 1;
-                let check_trimmed = check_line.trim();
-                // Look for prose indicators
-                if check_trimmed.len() > 20
-                    && (check_trimmed.contains(" the ")
-                        || check_trimmed.contains(" and ")
-                        || check_trimmed.contains(" or ")
-                        || check_trimmed.contains(" to ")
-                        || check_trimmed.contains(" of ")
-                        || check_trimmed.contains(" in ")
-                        || check_trimmed.contains(" is ")
-                        || check_trimmed.contains(" that "))
-                {
-                    has_prose_content = true;
-                }
-            }
-        }
-
-        // If we have many consecutive indented lines with prose content,
-        // it's likely formatted text, not code
-        if consecutive_indented_lines >= 5 && has_prose_content {
-            return true;
-        }
-
-        false
-    }
-
     /// Check if an indented line is part of a list structure
     fn is_part_of_list_structure(&self, lines: &[&str], i: usize) -> bool {
         // Look backwards to find if we're in a list context
@@ -224,6 +151,31 @@ impl MD046CodeBlockStyle {
         false
     }
 
+    /// Helper function to check if a line is part of MkDocs tab content
+    fn is_in_mkdocs_tab(&self, lines: &[&str], i: usize) -> bool {
+        // Look backwards for tab markers
+        for j in (0..i).rev() {
+            let line = lines[j];
+
+            // Check if this is a tab marker
+            if mkdocs_tabs::is_tab_marker(line) {
+                let tab_indent = mkdocs_tabs::get_tab_indent(line).unwrap_or(0);
+                // Check if current line has proper tab content indentation
+                if mkdocs_tabs::is_tab_content(lines[i], tab_indent) {
+                    return true;
+                }
+                // If we found a tab but indentation doesn't match, we're not in it
+                return false;
+            }
+
+            // If we hit a non-indented, non-empty line that's not a tab, stop searching
+            if !line.trim().is_empty() && !line.starts_with("    ") && !mkdocs_tabs::is_tab_marker(line) {
+                break;
+            }
+        }
+        false
+    }
+
     fn check_unclosed_code_blocks(
         &self,
         ctx: &crate::lint_context::LintContext,
@@ -247,6 +199,137 @@ impl MD046CodeBlockStyle {
                 // Count the fence length
                 let fence_length = trimmed.chars().take_while(|&c| c == fence_char).count();
 
+                // Check what comes after the fence characters
+                let after_fence = &trimmed[fence_length..];
+
+                // Check if this is a valid fence pattern
+                // Valid markdown code fence syntax:
+                // - ``` or ~~~ (just fence)
+                // - ``` language or ~~~ language (fence with space then language)
+                // - ```language (without space) is accepted by many parsers but only for actual languages
+                let is_valid_fence_pattern = if after_fence.is_empty() {
+                    // Empty after fence is always valid (e.g., ``` or ~~~)
+                    true
+                } else if after_fence.starts_with(' ') || after_fence.starts_with('\t') {
+                    // Space after fence - anything following is valid as info string
+                    true
+                } else {
+                    // No space after fence - must be a valid language identifier
+                    // Be strict to avoid false positives on content that looks like fences
+                    let identifier = after_fence.trim().to_lowercase();
+
+                    // Reject obvious non-language patterns
+                    if identifier.contains("fence") || identifier.contains("still") {
+                        false
+                    } else if identifier.len() > 20 {
+                        // Most language identifiers are short
+                        false
+                    } else if let Some(first_char) = identifier.chars().next() {
+                        // Must start with letter or # (for C#, F#)
+                        if !first_char.is_alphabetic() && first_char != '#' {
+                            false
+                        } else {
+                            // Check all characters are valid for a language identifier
+                            // Also check it's not just random text
+                            let valid_chars = identifier.chars().all(|c| {
+                                c.is_alphanumeric() || c == '-' || c == '_' || c == '+' || c == '#' || c == '.'
+                            });
+
+                            // Additional check: at least 2 chars and not all consonants (helps filter random words)
+                            valid_chars && identifier.len() >= 2
+                        }
+                    } else {
+                        false
+                    }
+                };
+
+                // When inside a code block, be conservative about what we treat as a fence
+                if !fence_stack.is_empty() {
+                    // Skip if not a valid fence pattern to begin with
+                    if !is_valid_fence_pattern {
+                        continue;
+                    }
+
+                    // Check if this could be a closing fence for the current block
+                    if let Some((open_marker, open_length, _, _, _)) = fence_stack.last() {
+                        if fence_char == open_marker.chars().next().unwrap() && fence_length >= *open_length {
+                            // Potential closing fence - check if it has content after
+                            if !after_fence.trim().is_empty() {
+                                // Has content after - likely not a closing fence
+                                // Apply structural validation to determine if it's a nested fence
+
+                                // Skip patterns that are clearly decorative or content
+                                // 1. Contains special characters not typical in language identifiers
+                                let has_special_chars = after_fence.chars().any(|c| {
+                                    !c.is_alphanumeric()
+                                        && c != '-'
+                                        && c != '_'
+                                        && c != '+'
+                                        && c != '#'
+                                        && c != '.'
+                                        && c != ' '
+                                        && c != '\t'
+                                });
+
+                                if has_special_chars {
+                                    continue; // e.g., ~~~!@#$%, ~~~~~~~~^^^^
+                                }
+
+                                // 2. Check for repetitive non-alphanumeric patterns
+                                if fence_length > 4 && after_fence.chars().take(4).all(|c| !c.is_alphanumeric()) {
+                                    continue; // e.g., ~~~~~~~~~~ or ````````
+                                }
+
+                                // 3. If no space after fence, must look like a valid language identifier
+                                if !after_fence.starts_with(' ') && !after_fence.starts_with('\t') {
+                                    let identifier = after_fence.trim();
+
+                                    // Must start with letter or # (for C#, F#)
+                                    if let Some(first) = identifier.chars().next()
+                                        && !first.is_alphabetic()
+                                        && first != '#'
+                                    {
+                                        continue;
+                                    }
+
+                                    // Reasonable length for a language identifier
+                                    if identifier.len() > 30 {
+                                        continue;
+                                    }
+                                }
+                            }
+                            // Otherwise, could be a closing fence - let it through
+                        } else {
+                            // Different fence type or insufficient length
+                            // Only treat as nested if it looks like a real fence with language
+
+                            // Must have proper spacing or no content after fence
+                            if !after_fence.is_empty()
+                                && !after_fence.starts_with(' ')
+                                && !after_fence.starts_with('\t')
+                            {
+                                // No space after fence - be very strict
+                                let identifier = after_fence.trim();
+
+                                // Skip if contains any special characters beyond common ones
+                                if identifier.chars().any(|c| {
+                                    !c.is_alphanumeric() && c != '-' && c != '_' && c != '+' && c != '#' && c != '.'
+                                }) {
+                                    continue;
+                                }
+
+                                // Skip if doesn't start with letter or #
+                                if let Some(first) = identifier.chars().next()
+                                    && !first.is_alphabetic()
+                                    && first != '#'
+                                {
+                                    continue;
+                                }
+                            }
+                        }
+                    }
+                }
+
                 // We'll check if this is a markdown block after determining if it's an opening fence
 
                 // Check if this is a closing fence for the current open fence
@@ -260,10 +343,10 @@ impl MD046CodeBlockStyle {
                             let _popped = fence_stack.pop();
 
                             // Check if we're exiting a markdown documentation block
-                            if let Some((_, _, _, _, is_md)) = _popped {
-                                if is_md {
-                                    inside_markdown_documentation_block = false;
-                                }
+                            if let Some((_, _, _, _, is_md)) = _popped
+                                && is_md
+                            {
+                                inside_markdown_documentation_block = false;
                             }
                             continue;
                         }
@@ -271,7 +354,7 @@ impl MD046CodeBlockStyle {
                 }
 
                 // This is an opening fence (has content after marker or no matching open fence)
-                let after_fence = &trimmed[fence_length..];
+                // Note: after_fence was already calculated above during validation
                 if !after_fence.trim().is_empty() || fence_stack.is_empty() {
                     // Only flag as problematic if we're opening a new fence while another is still open
                     // AND they use the same fence character (indicating potential confusion)
@@ -360,7 +443,7 @@ impl MD046CodeBlockStyle {
         Ok(warnings)
     }
 
-    fn detect_style(&self, content: &str) -> Option<CodeBlockStyle> {
+    fn detect_style(&self, content: &str, is_mkdocs: bool) -> Option<CodeBlockStyle> {
         // Empty content has no style
         if content.is_empty() {
             return None;
@@ -377,7 +460,7 @@ impl MD046CodeBlockStyle {
             if self.is_fenced_code_block_start(line) {
                 fenced_found = true;
                 fenced_line = fenced_line.min(i);
-            } else if self.is_indented_code_block(&lines, i) {
+            } else if self.is_indented_code_block(&lines, i, is_mkdocs) {
                 indented_found = true;
                 indented_line = indented_line.min(i);
             }
@@ -388,16 +471,16 @@ impl MD046CodeBlockStyle {
             None
         } else if fenced_found && !indented_found {
             // Only fenced blocks found
-            return Some(CodeBlockStyle::Fenced);
+            Some(CodeBlockStyle::Fenced)
         } else if !fenced_found && indented_found {
             // Only indented blocks found
-            return Some(CodeBlockStyle::Indented);
+            Some(CodeBlockStyle::Indented)
         } else {
             // Both types found - use the first one encountered
             if indented_line < fenced_line {
-                return Some(CodeBlockStyle::Indented);
+                Some(CodeBlockStyle::Indented)
             } else {
-                return Some(CodeBlockStyle::Fenced);
+                Some(CodeBlockStyle::Fenced)
             }
         }
     }
@@ -478,8 +561,9 @@ impl Rule for MD046CodeBlockStyle {
         let lines: Vec<&str> = content.lines().collect();
 
         // Determine target style
+        let is_mkdocs = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
         let target_style = match self.config.style {
-            CodeBlockStyle::Consistent => self.detect_style(content).unwrap_or(CodeBlockStyle::Fenced),
+            CodeBlockStyle::Consistent => self.detect_style(content, is_mkdocs).unwrap_or(CodeBlockStyle::Fenced),
             _ => self.config.style,
         };
 
@@ -528,11 +612,11 @@ impl Rule for MD046CodeBlockStyle {
                     result.push_str(line);
                     result.push('\n');
                 }
-            } else if self.is_indented_code_block(&lines, i) {
+            } else if self.is_indented_code_block(&lines, i, is_mkdocs) {
                 // This is an indented code block
 
                 // Check if we need to start a new fenced block
-                let prev_line_is_indented = i > 0 && self.is_indented_code_block(&lines, i - 1);
+                let prev_line_is_indented = i > 0 && self.is_indented_code_block(&lines, i - 1, is_mkdocs);
 
                 if target_style == CodeBlockStyle::Fenced {
                     if !prev_line_is_indented && !in_indented_block {
@@ -548,7 +632,8 @@ impl Rule for MD046CodeBlockStyle {
                     }
 
                     // Check if this is the end of the indented block
-                    let _next_line_is_indented = i < lines.len() - 1 && self.is_indented_code_block(&lines, i + 1);
+                    let _next_line_is_indented =
+                        i < lines.len() - 1 && self.is_indented_code_block(&lines, i + 1, is_mkdocs);
                     if !_next_line_is_indented && in_indented_block {
                         result.push_str("```\n");
                         in_indented_block = false;
@@ -576,11 +661,11 @@ impl Rule for MD046CodeBlockStyle {
         }
 
         // Close any unclosed fenced blocks
-        if let Some(fence_type) = fenced_fence_type {
-            if in_fenced_block {
-                result.push_str(fence_type);
-                result.push('\n');
-            }
+        if let Some(fence_type) = fenced_fence_type
+            && in_fenced_block
+        {
+            result.push_str(fence_type);
+            result.push('\n');
         }
 
         // Remove trailing newline if original didn't have one
@@ -664,6 +749,9 @@ impl Rule for MD046CodeBlockStyle {
         let line_index = LineIndex::new(ctx.content.to_string());
         let mut warnings = Vec::new();
 
+        // Check if we're in MkDocs mode
+        let is_mkdocs = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
+
         // Determine the target style from the detected style in the document
         let target_style = match self.config.style {
             CodeBlockStyle::Consistent => {
@@ -676,7 +764,7 @@ impl Rule for MD046CodeBlockStyle {
                         && (line.trim_start().starts_with("```") || line.trim_start().starts_with("~~~"))
                     {
                         first_fenced_line = i;
-                    } else if first_indented_line == usize::MAX && self.is_indented_code_block(&lines, i) {
+                    } else if first_indented_line == usize::MAX && self.is_indented_code_block(&lines, i, is_mkdocs) {
                         first_indented_line = i;
                     }
 
@@ -792,10 +880,10 @@ impl Rule for MD046CodeBlockStyle {
                 }
             }
             // Check for indented code blocks
-            else if !self.is_in_list(&lines, i) && self.is_indented_code_block(&lines, i) {
+            else if !self.is_in_list(&lines, i) && self.is_indented_code_block(&lines, i, is_mkdocs) {
                 if target_style == CodeBlockStyle::Fenced {
                     // Check if this is the start of a new indented block
-                    let prev_line_is_indented = i > 0 && self.is_indented_code_block(&lines, i - 1);
+                    let prev_line_is_indented = i > 0 && self.is_indented_code_block(&lines, i - 1, is_mkdocs);
 
                     if !prev_line_is_indented {
                         // Calculate precise character range for the entire indented line
@@ -875,7 +963,7 @@ mod tests {
     fn test_consistent_style_with_fenced_blocks() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "```\ncode\n```\n\nMore text\n\n```\nmore code\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // All blocks are fenced, so consistent style should be OK
@@ -886,7 +974,7 @@ mod tests {
     fn test_consistent_style_with_indented_blocks() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "Text\n\n    code\n    more code\n\nMore text\n\n    another block";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // All blocks are indented, so consistent style should be OK
@@ -897,7 +985,7 @@ mod tests {
     fn test_consistent_style_mixed() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "```\nfenced code\n```\n\nText\n\n    indented code\n\nMore";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Mixed styles should be flagged
@@ -908,7 +996,7 @@ mod tests {
     fn test_fenced_style_with_indented_blocks() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "Text\n\n    indented code\n    more code\n\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Indented blocks should be flagged when fenced style is required
@@ -920,7 +1008,7 @@ mod tests {
     fn test_indented_style_with_fenced_blocks() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Indented);
         let content = "Text\n\n```\nfenced code\n```\n\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Fenced blocks should be flagged when indented style is required
@@ -932,7 +1020,7 @@ mod tests {
     fn test_unclosed_code_block() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```\ncode without closing fence";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -943,7 +1031,7 @@ mod tests {
     fn test_nested_code_blocks() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```\nouter\n```\n\ninner text\n\n```\ncode\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // This should parse as two separate code blocks
@@ -954,7 +1042,7 @@ mod tests {
     fn test_fix_indented_to_fenced() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "Text\n\n    code line 1\n    code line 2\n\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("```\ncode line 1\ncode line 2\n```"));
@@ -964,7 +1052,7 @@ mod tests {
     fn test_fix_fenced_to_indented() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Indented);
         let content = "Text\n\n```\ncode line 1\ncode line 2\n```\n\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert!(fixed.contains("    code line 1\n    code line 2"));
@@ -975,7 +1063,7 @@ mod tests {
     fn test_fix_unclosed_block() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```\ncode without closing";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should add closing fence
@@ -986,7 +1074,7 @@ mod tests {
     fn test_code_block_in_list() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "- List item\n    code in list\n    more code\n- Next item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Code in lists should not be flagged
@@ -997,7 +1085,7 @@ mod tests {
     fn test_detect_style_fenced() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "```\ncode\n```";
-        let style = rule.detect_style(content);
+        let style = rule.detect_style(content, false);
 
         assert_eq!(style, Some(CodeBlockStyle::Fenced));
     }
@@ -1006,7 +1094,7 @@ mod tests {
     fn test_detect_style_indented() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "Text\n\n    code\n\nMore";
-        let style = rule.detect_style(content);
+        let style = rule.detect_style(content, false);
 
         assert_eq!(style, Some(CodeBlockStyle::Indented));
     }
@@ -1015,7 +1103,7 @@ mod tests {
     fn test_detect_style_none() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
         let content = "No code blocks here";
-        let style = rule.detect_style(content);
+        let style = rule.detect_style(content, false);
 
         assert_eq!(style, None);
     }
@@ -1024,7 +1112,7 @@ mod tests {
     fn test_tilde_fence() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "~~~\ncode\n~~~";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Tilde fences should be accepted as fenced blocks
@@ -1035,7 +1123,7 @@ mod tests {
     fn test_language_specification() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```rust\nfn main() {}\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1045,7 +1133,7 @@ mod tests {
     fn test_empty_content() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -1062,7 +1150,7 @@ mod tests {
     fn test_markdown_documentation_block() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```markdown\n# Example\n\n```\ncode\n```\n\nText\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Nested code blocks in markdown documentation should be allowed
@@ -1073,9 +1161,100 @@ mod tests {
     fn test_preserve_trailing_newline() {
         let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
         let content = "```\ncode\n```\n";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, content);
     }
+
+    #[test]
+    fn test_mkdocs_tabs_not_flagged_as_indented_code() {
+        let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+        let content = r#"# Document
+
+=== "Python"
+
+    This is tab content
+    Not an indented code block
+
+    ```python
+    def hello():
+        print("Hello")
+    ```
+
+=== "JavaScript"
+
+    More tab content here
+    Also not an indented code block"#;
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should not flag tab content as indented code blocks
+        assert_eq!(result.len(), 0);
+    }
+
+    #[test]
+    fn test_mkdocs_tabs_with_actual_indented_code() {
+        let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+        let content = r#"# Document
+
+=== "Tab 1"
+
+    This is tab content
+
+Regular text
+
+    This is an actual indented code block
+    Should be flagged"#;
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should flag the actual indented code block but not the tab content
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("Use fenced code blocks"));
+    }
+
+    #[test]
+    fn test_mkdocs_tabs_detect_style() {
+        let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
+        let content = r#"=== "Tab 1"
+
+    Content in tab
+    More content
+
+=== "Tab 2"
+
+    Content in second tab"#;
+
+        // In MkDocs mode, tab content should not be detected as indented code blocks
+        let style = rule.detect_style(content, true);
+        assert_eq!(style, None); // No code blocks detected
+
+        // In standard mode, it would detect indented code blocks
+        let style = rule.detect_style(content, false);
+        assert_eq!(style, Some(CodeBlockStyle::Indented));
+    }
+
+    #[test]
+    fn test_mkdocs_nested_tabs() {
+        let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+        let content = r#"# Document
+
+=== "Outer Tab"
+
+    Some content
+
+    === "Nested Tab"
+
+        Nested tab content
+        Should not be flagged"#;
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::MkDocs);
+        let result = rule.check(&ctx).unwrap();
+
+        // Nested tabs should not be flagged
+        assert_eq!(result.len(), 0);
+    }
 }
