@@ -283,6 +283,10 @@ impl Rule for MD054LinkImageStyle {
         ))
     }
 
+    fn fix_capability(&self) -> crate::rule::FixCapability {
+        crate::rule::FixCapability::Unfixable
+    }
+
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
@@ -313,7 +317,7 @@ mod tests {
     fn test_all_styles_allowed_by_default() {
         let rule = MD054LinkImageStyle::new(true, true, true, true, true, true);
         let content = "[inline](url) [ref][] [ref] <autolink> [full][ref] [url](url)\n\n[ref]: url";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -323,7 +327,7 @@ mod tests {
     fn test_only_inline_allowed() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[allowed](url) [not][ref] <https://bad.com> [bad][] [shortcut]\n\n[ref]: url\n[shortcut]: url";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 4);
@@ -337,7 +341,7 @@ mod tests {
     fn test_only_autolink_allowed() {
         let rule = MD054LinkImageStyle::new(true, false, false, false, false, false);
         let content = "<https://good.com> [bad](url) [bad][ref]\n\n[ref]: url";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -349,7 +353,7 @@ mod tests {
     fn test_url_inline_detection() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, true);
         let content = "[https://example.com](https://example.com) [text](https://example.com)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // First is url_inline (allowed), second is inline (allowed)
@@ -360,7 +364,7 @@ mod tests {
     fn test_url_inline_not_allowed() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[https://example.com](https://example.com)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -371,7 +375,7 @@ mod tests {
     fn test_shortcut_vs_full_detection() {
         let rule = MD054LinkImageStyle::new(false, false, true, false, false, false);
         let content = "[shortcut] [full][ref]\n\n[shortcut]: url\n[ref]: url2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only shortcut should be flagged
@@ -383,7 +387,7 @@ mod tests {
     fn test_collapsed_reference() {
         let rule = MD054LinkImageStyle::new(false, true, false, false, false, false);
         let content = "[collapsed][] [bad][ref]\n\n[collapsed]: url\n[ref]: url2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -394,7 +398,7 @@ mod tests {
     fn test_code_blocks_ignored() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "```\n[ignored](url) <https://ignored.com>\n```\n\n[checked](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only the link outside code block should be checked
@@ -405,7 +409,7 @@ mod tests {
     fn test_code_spans_ignored() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "`[ignored](url)` and `<https://ignored.com>` but [checked](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only the link outside code spans should be checked
@@ -416,7 +420,7 @@ mod tests {
     fn test_reference_definitions_ignored() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[ref]: https://example.com\n[ref2]: <https://example2.com>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Reference definitions should be ignored
@@ -427,7 +431,7 @@ mod tests {
     fn test_html_comments_ignored() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "<!-- [ignored](url) -->\n  <!-- <https://ignored.com> -->";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -437,7 +441,7 @@ mod tests {
     fn test_unicode_support() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[café ☕](https://café.com) [emoji 😀](url) [한글](url) [עברית](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // All should be detected as inline (allowed)
@@ -448,7 +452,7 @@ mod tests {
     fn test_line_positions() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "Line 1\n\nLine 3 with <https://bad.com> here";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -460,7 +464,7 @@ mod tests {
     fn test_multiple_links_same_line() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[ok](url) but <bad> and [also][bad]\n\n[bad]: url";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -472,7 +476,7 @@ mod tests {
     fn test_empty_content() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -482,7 +486,7 @@ mod tests {
     fn test_no_links() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "Just plain text without any links";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -492,7 +496,7 @@ mod tests {
     fn test_fix_returns_error() {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         let content = "[link](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.fix(&ctx);
 
         assert!(result.is_err());
@@ -506,7 +510,7 @@ mod tests {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         // Test that [text][ref] is detected as full, not shortcut
         let content = "[text][ref] not detected as [shortcut]\n\n[ref]: url\n[shortcut]: url2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -519,7 +523,7 @@ mod tests {
         let rule = MD054LinkImageStyle::new(false, false, false, true, true, false);
         // [text][ should not be detected as shortcut
         let content = "[text][ more text\n[text](url) is inline";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only second line should have inline link
@@ -531,7 +535,7 @@ mod tests {
         let rule = MD054LinkImageStyle::new(false, false, false, true, false, false);
         // Test with zero-width joiners and complex Unicode
         let content = "[👨‍👩‍👧‍👦 family](url) [café☕](https://café.com)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Both should be detected as inline (allowed)
