@@ -1,5 +1,6 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rule_config_serde::RuleConfig;
+use crate::utils::kramdown_utils::is_kramdown_block_attribute;
 use crate::utils::range_utils::LineIndex;
 use crate::utils::table_utils::TableUtils;
 use serde::{Deserialize, Serialize};
@@ -149,31 +150,41 @@ impl Rule for MD058BlanksAroundTables {
 
             // Check for sufficient blank lines after table
             if table_block.end_line < lines.len() - 1 {
-                let blank_lines_after = self.count_blank_lines_after(&lines, table_block.end_line);
-                if blank_lines_after < self.config.minimum_after {
-                    let needed = self.config.minimum_after - blank_lines_after;
-                    let message = if self.config.minimum_after == 1 {
-                        "Missing blank line after table".to_string()
-                    } else {
-                        format!("Missing {needed} blank lines after table")
-                    };
+                // Check if the next line is a Kramdown block attribute
+                let next_line_is_attribute = if table_block.end_line + 1 < lines.len() {
+                    is_kramdown_block_attribute(lines[table_block.end_line + 1])
+                } else {
+                    false
+                };
 
-                    warnings.push(LintWarning {
-                        rule_name: Some(self.name()),
-                        message,
-                        line: table_block.end_line + 1,
-                        column: lines[table_block.end_line].len() + 1,
-                        end_line: table_block.end_line + 1,
-                        end_column: lines[table_block.end_line].len() + 2,
-                        severity: Severity::Warning,
-                        fix: Some(Fix {
-                            range: _line_index.line_col_to_byte_range(
-                                table_block.end_line + 1,
-                                lines[table_block.end_line].len() + 1,
-                            ),
-                            replacement: format!("{}{}", lines[table_block.end_line], "\n".repeat(needed)),
-                        }),
-                    });
+                // Skip check if next line is a block attribute
+                if !next_line_is_attribute {
+                    let blank_lines_after = self.count_blank_lines_after(&lines, table_block.end_line);
+                    if blank_lines_after < self.config.minimum_after {
+                        let needed = self.config.minimum_after - blank_lines_after;
+                        let message = if self.config.minimum_after == 1 {
+                            "Missing blank line after table".to_string()
+                        } else {
+                            format!("Missing {needed} blank lines after table")
+                        };
+
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            message,
+                            line: table_block.end_line + 1,
+                            column: lines[table_block.end_line].len() + 1,
+                            end_line: table_block.end_line + 1,
+                            end_column: lines[table_block.end_line].len() + 2,
+                            severity: Severity::Warning,
+                            fix: Some(Fix {
+                                range: _line_index.line_col_to_byte_range(
+                                    table_block.end_line + 1,
+                                    lines[table_block.end_line].len() + 1,
+                                ),
+                                replacement: format!("{}{}", lines[table_block.end_line], "\n".repeat(needed)),
+                            }),
+                        });
+                    }
                 }
             }
         }
@@ -300,7 +311,7 @@ mod tests {
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -315,7 +326,7 @@ Some text after.";
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -332,7 +343,7 @@ Some text after.";
 |----------|----------|
 | Cell 1   | Cell 2   |
 Some text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -348,7 +359,7 @@ Some text after.";
 |----------|----------|
 | Cell 1   | Cell 2   |
 Some text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -364,7 +375,7 @@ Some text after.";
 | Cell 1   | Cell 2   |
 
 Some text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // No blank line needed before table at start of document
@@ -379,7 +390,7 @@ Some text after.";
 | Header 1 | Header 2 |
 |----------|----------|
 | Cell 1   | Cell 2   |";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // No blank line needed after table at end of document
@@ -398,7 +409,7 @@ Text between tables.
 |--------|-------|
 | Data 2 | Val 2 |
 Text after second table.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 4);
@@ -424,7 +435,7 @@ Text after second table.";
 | Data 2 | Val 2 |
 
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Tables separated by blank line should be OK
@@ -446,7 +457,7 @@ Text between.
 | Data 2 | Val 2 |
 
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should flag missing blanks around both tables
@@ -463,7 +474,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 Text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Text before.
@@ -488,7 +499,7 @@ Middle
 |----|----|
 | D2 | V2 |
 End";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Start
@@ -511,7 +522,7 @@ End";
     fn test_empty_content() {
         let rule = MD058BlanksAroundTables::default();
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -523,7 +534,7 @@ End";
         let content = "Just regular text.
 No tables here.
 Only paragraphs.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -539,7 +550,7 @@ Only paragraphs.";
 | In  | Code | Block |
 ```
 Text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Tables in code blocks should be ignored
@@ -555,7 +566,7 @@ Text after.";
 | Left     | Center   | Right    |
 | Data     | More     | Info     |
 ## Another Heading";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -574,7 +585,7 @@ Text after.";
 | O   |     | X   |
 
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -589,7 +600,7 @@ More text.";
 | 田中 | 25   | 東京 |
 | 佐藤 | 30   | 大阪 |
 End.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -605,7 +616,7 @@ End.";
 | Data  | This is an extremely long cell content that goes on |
 
 After.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -618,7 +629,7 @@ After.";
 | Header 1 | Header 2 |
 |----------|----------|
 Next paragraph.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should still require blanks around header-only table
@@ -635,7 +646,7 @@ Next paragraph.";
     | Data     | Here  |
 
     More content.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Indented tables should be detected
@@ -650,7 +661,7 @@ Next paragraph.";
 |--------|
 | Column |
 Text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Single column tables are not detected by table_utils (requires 2+ columns)
@@ -672,7 +683,7 @@ Text after.";
 | Cell   | Data  |
 
 Text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should pass with 1 blank line before (but we configured to require 2)
@@ -695,7 +706,7 @@ Text after.";
 | Cell   | Data  |
 
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should fail with only 1 blank line after (but we configured to require 3)
@@ -716,7 +727,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should fail both before and after
@@ -738,7 +749,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 More text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should pass with zero blank lines required
@@ -758,7 +769,7 @@ More text.";
 |--------|-------|
 | Cell   | Data  |
 Text after.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         let expected = "Text before.
@@ -811,4 +822,34 @@ Text after.";
         // Test at end
         assert_eq!(rule.count_blank_lines_after(&lines, 6), 0);
     }
+
+    #[test]
+    fn test_issue_25_table_with_long_line() {
+        // Test case from issue #25 - table with very long line
+        let rule = MD058BlanksAroundTables::default();
+        let content = "# Title\n\nThis is a table:\n\n| Name          | Query                                                    |\n| ------------- | -------------------------------------------------------- |\n| b             | a                                                        |\n| c             | a                                                        |\n| d             | a                                                        |\n| long          | aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa |\n| e             | a                                                        |\n| f             | a                                                        |\n| g             | a                                                        |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+
+        // Debug: Print detected table blocks
+        let table_blocks = TableUtils::find_table_blocks(content, &ctx);
+        for (i, block) in table_blocks.iter().enumerate() {
+            eprintln!(
+                "Table {}: start={}, end={}, header={}, delimiter={}, content_lines={:?}",
+                i + 1,
+                block.start_line + 1,
+                block.end_line + 1,
+                block.header_line + 1,
+                block.delimiter_line + 1,
+                block.content_lines.iter().map(|x| x + 1).collect::<Vec<_>>()
+            );
+        }
+
+        let result = rule.check(&ctx).unwrap();
+
+        // This should detect one table, not multiple tables
+        assert_eq!(table_blocks.len(), 1, "Should detect exactly one table block");
+
+        // Should not flag any issues since table is complete and doesn't need blanks
+        assert_eq!(result.len(), 0, "Should not flag any MD058 issues for a complete table");
+    }
 }
