@@ -10,11 +10,11 @@ pub mod comprehensive_tests;
 pub mod extended_tests;
 pub mod unicode_utils;
 
-use rumdl::lint_context::LintContext;
-use rumdl::rule::{LintWarning, Rule};
-use rumdl::rules::heading_utils::HeadingStyle;
-use rumdl::rules::md004_unordered_list_style::UnorderedListStyle;
-use rumdl::rules::*;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::{LintWarning, Rule};
+use rumdl_lib::rules::heading_utils::HeadingStyle;
+use rumdl_lib::rules::md004_unordered_list_style::UnorderedListStyle;
+use rumdl_lib::rules::*;
 
 /// Represents a single character range test case
 #[derive(Debug, Clone)]
@@ -64,7 +64,7 @@ pub fn test_character_ranges(test: CharacterRangeTest) {
     let rule = create_rule_by_name(test.rule_name).unwrap_or_else(|| panic!("Unknown rule: {}", test.rule_name));
 
     // Run the rule check
-    let ctx = LintContext::new(test.content);
+    let ctx = LintContext::new(test.content, rumdl_lib::config::MarkdownFlavor::Standard);
     let warnings = rule
         .check(&ctx)
         .unwrap_or_else(|e| panic!("Rule {} failed to check content: {}", test.rule_name, e));
@@ -195,11 +195,11 @@ pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
         "MD002" => Some(Box::new(MD002FirstHeadingH1::new(1))),
         "MD003" => Some(Box::new(MD003HeadingStyle::new(HeadingStyle::Consistent))),
         "MD004" => Some(Box::new(MD004UnorderedListStyle::new(UnorderedListStyle::Consistent))),
-        "MD005" => Some(Box::new(MD005ListIndent)),
+        "MD005" => Some(Box::new(MD005ListIndent::default())),
         "MD006" => Some(Box::new(MD006StartBullets)),
         "MD007" => Some(Box::new(MD007ULIndent::new(2))),
         "MD009" => Some(Box::new(MD009TrailingSpaces::new(2, false))),
-        "MD010" => Some(Box::new(MD010NoHardTabs::new(4, false))),
+        "MD010" => Some(Box::new(MD010NoHardTabs::new(4))),
         "MD011" => Some(Box::new(MD011NoReversedLinks)),
         "MD012" => Some(Box::new(MD012NoMultipleBlanks::new(1))),
         "MD013" => Some(Box::new(MD013LineLength::new(80, true, true, true, false))),
@@ -226,12 +226,12 @@ pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
         "MD039" => Some(Box::new(MD039NoSpaceInLinks)),
         "MD040" => Some(Box::new(MD040FencedCodeLanguage)),
         "MD041" => Some(Box::new(MD041FirstLineHeading::new(1, false))),
-        "MD042" => Some(Box::new(MD042NoEmptyLinks)),
+        "MD042" => Some(Box::new(MD042NoEmptyLinks::new())),
         "MD043" => Some(Box::new(MD043RequiredHeadings::new(vec![]))),
         "MD044" => Some(Box::new(MD044ProperNames::new(vec![], false))),
         "MD045" => Some(Box::new(MD045NoAltText::new())),
         "MD047" => Some(Box::new(MD047SingleTrailingNewline)),
-        "MD051" => Some(Box::new(MD051LinkFragments)),
+        "MD051" => Some(Box::new(MD051LinkFragments::new())),
         "MD053" => Some(Box::new(MD053LinkImageReferenceDefinitions::default())),
         _ => None,
     }
@@ -273,7 +273,7 @@ mod tests {
             end_line: 1,
             end_column: 8,
             message: "test".to_string(),
-            severity: rumdl::rule::Severity::Warning,
+            severity: rumdl_lib::rule::Severity::Warning,
             fix: None,
         };
 
@@ -291,7 +291,7 @@ mod tests {
             end_line: 2,
             end_column: 5,
             message: "test".to_string(),
-            severity: rumdl::rule::Severity::Warning,
+            severity: rumdl_lib::rule::Severity::Warning,
             fix: None,
         };
 
