@@ -9,9 +9,9 @@
 
 #![allow(deprecated)]
 
-use rumdl::lsp::RumdlLanguageServer;
-use rumdl::lsp::types::{RumdlLspConfig, warning_to_code_action, warning_to_diagnostic};
-use rumdl::rule::{Fix, LintWarning, Severity};
+use rumdl_lib::lsp::RumdlLanguageServer;
+use rumdl_lib::lsp::types::{RumdlLspConfig, warning_to_code_action, warning_to_diagnostic};
+use rumdl_lib::rule::{Fix, LintWarning, Severity};
 use tower_lsp::lsp_types::*;
 use tower_lsp::{LanguageServer, LspService};
 use url::Url;
@@ -24,7 +24,6 @@ fn test_rumdl_lsp_config_defaults() {
     assert_eq!(config.config_path, None);
     assert!(config.enable_linting);
     assert!(!config.enable_auto_fix);
-    assert!(config.disable_rules.is_empty());
 }
 
 /// Test the RumdlLspConfig serialization/deserialization
@@ -34,7 +33,8 @@ fn test_rumdl_lsp_config_serde() {
         config_path: Some("/path/to/config.toml".to_string()),
         enable_linting: true,
         enable_auto_fix: false,
-        disable_rules: vec!["MD001".to_string(), "MD013".to_string()],
+        enable_rules: None,
+        disable_rules: None,
     };
 
     // Test serialization
@@ -46,7 +46,6 @@ fn test_rumdl_lsp_config_serde() {
     assert_eq!(deserialized.config_path, config.config_path);
     assert_eq!(deserialized.enable_linting, config.enable_linting);
     assert_eq!(deserialized.enable_auto_fix, config.enable_auto_fix);
-    assert_eq!(deserialized.disable_rules, config.disable_rules);
 }
 
 /// Test warning to diagnostic conversion
@@ -191,6 +190,10 @@ async fn test_lsp_server_initialization() {
     assert!(caps.text_document_sync.is_some());
     assert!(caps.code_action_provider.is_some());
     assert!(caps.diagnostic_provider.is_some());
+    assert!(
+        caps.document_formatting_provider.is_some(),
+        "Server must advertise document formatting capability"
+    );
 
     // Check server info
     assert!(init_result.server_info.is_some());
@@ -208,7 +211,8 @@ async fn test_lsp_server_initialization_with_config() {
         config_path: Some("/custom/path/.rumdl.toml".to_string()),
         enable_linting: true,
         enable_auto_fix: true,
-        disable_rules: vec!["MD001".to_string()],
+        enable_rules: None,
+        disable_rules: None,
     };
 
     let init_params = InitializeParams {
