@@ -1,6 +1,6 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::{MD004UnorderedListStyle, MD005ListIndent, MD007ULIndent, MD029OrderedListPrefix};
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::{MD004UnorderedListStyle, MD005ListIndent, MD007ULIndent, MD029OrderedListPrefix};
 
 /// Cross-rule integration tests for list rules (MD004, MD005, MD007, MD029)
 ///
@@ -11,7 +11,7 @@ use rumdl::rules::{MD004UnorderedListStyle, MD005ListIndent, MD007ULIndent, MD02
 fn test_mixed_unordered_list_style_and_indentation() {
     // Test MD004 (unordered list style) + MD005 (list indentation) + MD007 (unordered list indentation)
     let md004 = MD004UnorderedListStyle::default(); // Consistent marker style
-    let md005 = MD005ListIndent; // Consistent indentation
+    let md005 = MD005ListIndent::default(); // Consistent indentation
     let md007 = MD007ULIndent::default(); // Proper nested indentation
 
     let content = "\
@@ -20,7 +20,7 @@ fn test_mixed_unordered_list_style_and_indentation() {
  * Wrong indent 1 space (MD005, MD007 violations)
 * Third item back to asterisk";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // All rules should detect their respective issues
     let md004_result = md004.check(&ctx).unwrap();
@@ -33,7 +33,7 @@ fn test_mixed_unordered_list_style_and_indentation() {
 
     // Test that fixing MD004 doesn't break others
     let md004_fixed = md004.fix(&ctx).unwrap();
-    let ctx_after_md004 = LintContext::new(&md004_fixed);
+    let ctx_after_md004 = LintContext::new(&md004_fixed, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // MD004 issues should be resolved
     let md004_recheck = md004.check(&ctx_after_md004).unwrap();
@@ -56,7 +56,7 @@ fn test_mixed_unordered_list_style_and_indentation() {
 fn test_ordered_list_style_and_indentation() {
     // Test MD029 (ordered list prefix) + MD005 (list indentation)
     let md029 = MD029OrderedListPrefix::default(); // Sequential numbering
-    let md005 = MD005ListIndent; // Consistent indentation
+    let md005 = MD005ListIndent::default(); // Consistent indentation
 
     let content = "\
 1. First item
@@ -64,7 +64,7 @@ fn test_ordered_list_style_and_indentation() {
  2. Wrong indent and number (MD005, MD029 violations)
 4. Fourth item";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Both rules should detect their respective issues
     let md029_result = md029.check(&ctx).unwrap();
@@ -75,7 +75,7 @@ fn test_ordered_list_style_and_indentation() {
 
     // Test that fixing MD029 doesn't break MD005
     let md029_fixed = md029.fix(&ctx).unwrap();
-    let ctx_after_md029 = LintContext::new(&md029_fixed);
+    let ctx_after_md029 = LintContext::new(&md029_fixed, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // MD029 issues should be resolved
     let md029_recheck = md029.check(&ctx_after_md029).unwrap();
@@ -93,7 +93,7 @@ fn test_ordered_list_style_and_indentation() {
 fn test_complex_nested_mixed_lists() {
     // Test all list rules together with complex nesting
     let md004 = MD004UnorderedListStyle::default();
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md007 = MD007ULIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
@@ -106,7 +106,7 @@ fn test_complex_nested_mixed_lists() {
   5. Wrong ordered number (MD029 violation)
 * Back to proper unordered";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // All rules should work independently
     let md004_result = md004.check(&ctx).unwrap();
@@ -121,16 +121,16 @@ fn test_complex_nested_mixed_lists() {
 
     // Apply fixes sequentially and ensure they don't conflict
     let step1 = md004.fix(&ctx).unwrap();
-    let ctx1 = LintContext::new(&step1);
+    let ctx1 = LintContext::new(&step1, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let step2 = md005.fix(&ctx1).unwrap();
-    let ctx2 = LintContext::new(&step2);
+    let ctx2 = LintContext::new(&step2, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let step3 = md007.fix(&ctx2).unwrap();
-    let ctx3 = LintContext::new(&step3);
+    let ctx3 = LintContext::new(&step3, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let step4 = md029.fix(&ctx3).unwrap();
-    let ctx_final = LintContext::new(&step4);
+    let ctx_final = LintContext::new(&step4, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // After all fixes, all rules should be satisfied
     assert!(
@@ -154,7 +154,7 @@ fn test_complex_nested_mixed_lists() {
 #[test]
 fn test_deep_nesting_with_multiple_list_types() {
     // Test how rules handle deeply nested lists with multiple types
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md007 = MD007ULIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
@@ -167,7 +167,7 @@ fn test_deep_nesting_with_multiple_list_types() {
    * Back to second level
 2. Second top level";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // With proper indentation, all rules should pass
     let md005_result = md005.check(&ctx).unwrap();
@@ -176,20 +176,18 @@ fn test_deep_nesting_with_multiple_list_types() {
 
     assert!(md005_result.is_empty(), "MD005 should pass with proper indentation");
     assert!(md007_result.is_empty(), "MD007 should pass with proper nesting");
-    // MD029 should detect that "2. Second top level" starts a new list after nested content
-    assert_eq!(md029_result.len(), 1, "MD029 should detect numbering issue");
-    assert_eq!(md029_result[0].line, 7, "Should detect issue on line 7");
-    assert!(md029_result[0].message.contains("2"), "Should mention actual number 2");
+    // MD029 should pass - the sequence "1. ... 2." is correct with sequential numbering
+    // The nested content doesn't interrupt the top-level ordered list
     assert!(
-        md029_result[0].message.contains("1"),
-        "Should mention expected number 1"
+        md029_result.is_empty(),
+        "MD029 should pass with correct sequential numbering"
     );
 }
 
 #[test]
 fn test_list_rules_with_code_blocks() {
     // Test that list rules handle code blocks correctly without interference
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
     let content = "\
@@ -207,7 +205,7 @@ fn test_list_rules_with_code_blocks() {
    ```
 3. Third item";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Code blocks should not interfere with list rule detection
     let md005_result = md005.check(&ctx).unwrap();
@@ -223,7 +221,7 @@ fn test_list_rules_with_code_blocks() {
 #[test]
 fn test_list_rules_with_blockquotes() {
     // Test that list rules work correctly inside blockquotes
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
     let content = "\
@@ -236,7 +234,7 @@ fn test_list_rules_with_blockquotes() {
 > * Unordered list in quote
 >   * Nested unordered in quote";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Rules should work correctly within blockquotes
     let md005_result = md005.check(&ctx).unwrap();
@@ -256,7 +254,7 @@ fn test_list_rules_with_blockquotes() {
 fn test_list_continuation_across_rules() {
     // Test that list continuation works across different rule fixes
     let md004 = MD004UnorderedListStyle::default();
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
 
     let content = "\
 * First item
@@ -266,7 +264,7 @@ fn test_list_continuation_across_rules() {
   * Nested item
     Nested continuation";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Both rules should handle continuation text correctly
     let md004_result = md004.check(&ctx).unwrap();
@@ -280,7 +278,7 @@ fn test_list_continuation_across_rules() {
 
     // Fix MD004 and ensure continuation text is preserved
     let md004_fixed = md004.fix(&ctx).unwrap();
-    let ctx_fixed = LintContext::new(&md004_fixed);
+    let ctx_fixed = LintContext::new(&md004_fixed, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Continuation text should still be properly indented
     let md005_after_fix = md005.check(&ctx_fixed).unwrap();
@@ -305,7 +303,7 @@ fn test_list_continuation_across_rules() {
 fn test_empty_lines_between_list_items() {
     // Test that empty lines between list items don't interfere with rules
     let md004 = MD004UnorderedListStyle::default();
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
     let content = "\
@@ -321,7 +319,7 @@ fn test_empty_lines_between_list_items() {
 
 4. Fourth item";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Empty lines should not break rule detection
     let md004_result = md004.check(&ctx).unwrap();
@@ -341,10 +339,11 @@ fn test_empty_lines_between_list_items() {
 }
 
 #[test]
+#[ignore] // Skip in normal test runs - performance test
 fn test_performance_with_large_mixed_lists() {
     // Test performance and correctness with larger list structures
     let md004 = MD004UnorderedListStyle::default();
-    let md005 = MD005ListIndent;
+    let md005 = MD005ListIndent::default();
     let md007 = MD007ULIndent::default();
     let md029 = MD029OrderedListPrefix::default();
 
@@ -364,7 +363,7 @@ fn test_performance_with_large_mixed_lists() {
         }
     }
 
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // All rules should handle large structures efficiently
     let start = std::time::Instant::now();
