@@ -1,5 +1,5 @@
-use rumdl::rule::Rule;
-use rumdl::rules::MD043RequiredHeadings;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD043RequiredHeadings;
 
 #[test]
 fn test_matching_headings() {
@@ -10,7 +10,7 @@ fn test_matching_headings() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Methods\n\n# Results";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -24,11 +24,12 @@ fn test_missing_heading() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Results";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Introduction\n\n# Methods\n\n# Results");
+    // MD043 now preserves original content to prevent data loss
+    assert_eq!(fixed, content);
 }
 
 #[test]
@@ -36,11 +37,12 @@ fn test_extra_heading() {
     let required = vec!["# Introduction".to_string(), "# Results".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Methods\n\n# Results";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Introduction\n\n# Results");
+    // MD043 now preserves original content to prevent data loss
+    assert_eq!(fixed, content);
 }
 
 #[test]
@@ -52,11 +54,12 @@ fn test_wrong_order() {
     ];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\n\n# Results\n\n# Methods";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Introduction\n\n# Methods\n\n# Results");
+    // MD043 now preserves original content to prevent data loss
+    assert_eq!(fixed, content);
 }
 
 #[test]
@@ -64,7 +67,7 @@ fn test_empty_required_headings() {
     let required = vec![];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Any heading\n\n# Another heading";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
     let fixed = rule.fix(&ctx).unwrap();
@@ -76,7 +79,7 @@ fn test_case_sensitive() {
     let required = vec!["# Introduction".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# INTRODUCTION";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty()); // Should match because match_case is false by default
 }
@@ -86,7 +89,7 @@ fn test_mixed_heading_styles() {
     let required = vec!["# Introduction".to_string(), "======= Methods".to_string()];
     let rule = MD043RequiredHeadings::new(required);
     let content = "# Introduction\nContent\nMethods\n=======";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
