@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD047SingleTrailingNewline;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD047SingleTrailingNewline;
 
 #[test]
 fn test_valid_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_file_end_newline() {
 fn test_missing_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -24,7 +24,7 @@ fn test_missing_file_end_newline() {
 fn test_multiple_file_end_newlines() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text\n\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -33,7 +33,7 @@ fn test_multiple_file_end_newlines() {
 fn test_fix_file_end_newline() {
     let rule = MD047SingleTrailingNewline;
     let content = "Some text\nMore text";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "Some text\nMore text\n");
 }
