@@ -2,6 +2,7 @@ mod md001_test;
 mod md002_test;
 mod md003_test;
 mod md004_test;
+mod md005_dynamic_indent_test;
 mod md005_test;
 mod md006_test;
 mod md007_test;
@@ -20,18 +21,27 @@ mod md023_extended_test;
 mod md023_test;
 mod md024_test;
 mod md025_test;
+mod md026_kramdown_test;
 mod md026_test;
 mod md027_test;
 mod md028_test;
+mod md029_code_block_separation_test;
+mod md029_fix_test;
+mod md029_issue42_test;
+mod md029_markdownlint_parity_test;
 mod md029_test;
 mod md030_test;
+mod md031_kramdown_test;
 mod md031_test;
 mod md032_test;
+mod md033_kramdown_test;
+// mod md033_extended_test; // Temporarily disabled - needs LintContext fixes
 mod md033_test;
 mod md034_ipv6_test;
 mod md034_test;
 mod md035_test;
 mod md036_test;
+mod md037_kramdown_test;
 mod md037_test;
 mod md038_nested_backticks_test;
 mod md038_test;
@@ -47,8 +57,17 @@ mod md047_test;
 mod md048_test;
 mod md049_test;
 mod md050_test;
+mod md051_comprehensive_test;
+mod md051_critical_edge_cases_test;
+mod md051_edge_cases_test;
+mod md051_issue_39_regression_test;
+// mod md051_kramdown_official_test;
+mod md051_performance_edge_cases_test;
+mod md051_property_based_test;
+mod md051_regression_prevention_test;
 mod md051_test;
-mod md051_unicode_test;
+mod md051_unicode_security_test;
+// mod md051_unicode_test;
 mod md052_test;
 mod md053_additional_test;
 mod md053_test;
@@ -56,6 +75,7 @@ mod md054_test;
 mod md055_test;
 mod md056_test;
 mod md057_test;
+mod md058_kramdown_test;
 mod md058_test;
 
 // Unicode-specific test modules
@@ -71,6 +91,12 @@ mod heading_edge_cases_test;
 mod inline_content_edge_cases_test;
 mod link_edge_cases_test;
 mod list_rules_integration_test;
+mod md028_md009_interaction_test;
+mod mkdocs_admonitions_test;
+mod mkdocs_edge_cases_test;
+mod mkdocs_extensions_test;
+mod mkdocs_snippets_test;
+mod rule_interaction_test;
 
 // Test cases for MD003 - Heading Style
 #[test]
