@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::*;
-use rumdl::utils::fix_utils::apply_warning_fixes;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::*;
+use rumdl_lib::utils::fix_utils::apply_warning_fixes;
 
 #[test]
 fn test_unicode_cli_lsp_consistency() {
     // Unicode content similar to our test file but smaller for focused testing
-    let unicode_content = r#"# 🚀 This is a header with emoji 
+    let unicode_content = r#"# 🚀 This is a header with emoji
 مرحبا بكم في هذا النص العربي
 (https://例え.テスト)[Japanese domain link]
 Here is some `中文代码` in inline code
@@ -22,7 +22,7 @@ Here is some `中文代码` in inline code
     ];
 
     for rule in &rules {
-        let ctx = LintContext::new(unicode_content);
+        let ctx = LintContext::new(unicode_content, rumdl_lib::config::MarkdownFlavor::Standard);
 
         // Get warnings from check method (LSP style)
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
@@ -99,7 +99,7 @@ fn test_complex_unicode_scenarios() {
     let rule = MD047SingleTrailingNewline;
 
     for (content, description) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
         // Test that rule can handle the content without panicking
         let warnings_result = rule.check(&ctx);
@@ -151,7 +151,7 @@ fn test_unicode_byte_boundary_validation() {
     ];
 
     for rule in &rules {
-        let ctx = LintContext::new(unicode_content);
+        let ctx = LintContext::new(unicode_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
 
         for warning in &warnings {
